__all__=['', 'STARTUPINFO', 'beginthreadex', 'CreateRemoteThread', 'CreateProcess', 'CreateProcessAsUser', 'GetCurrentProcess', 'GetProcessVersion', 'GetCurrentProcessId', 'GetStartupInfo', 'GetPriorityClass', 'GetExitCodeThread', 'GetExitCodeProcess', 'GetWindowThreadProcessId', 'SetThreadPriority', 'GetThreadPriority', 'GetProcessPriorityBoost', 'SetProcessPriorityBoost', 'GetThreadPriorityBoost', 'SetThreadPriorityBoost', 'GetThreadIOPendingFlag', 'GetThreadTimes', 'GetProcessId', 'SetPriorityClass', 'AttachThreadInput', 'SetThreadIdealProcessor', 'GetProcessAffinityMask', 'SetProcessAffinityMask', 'SetThreadAffinityMask', 'SuspendThread', 'ResumeThread', 'TerminateProcess', 'ExitProcess', 'EnumProcesses', 'EnumProcessModules', 'EnumProcessModulesEx', 'GetModuleFileNameEx', 'GetProcessMemoryInfo', 'GetProcessTimes', 'GetProcessIoCounters', 'GetProcessWindowStation', 'GetProcessWorkingSetSize', 'SetProcessWorkingSetSize', 'GetProcessShutdownParameters', 'SetProcessShutdownParameters', 'GetGuiResources', 'IsWow64Process', 'ABOVE_NORMAL_PRIORITY_CLASS', 'BELOW_NORMAL_PRIORITY_CLASS', 'CREATE_BREAKAWAY_FROM_JOB', 'CREATE_DEFAULT_ERROR_MODE', 'CREATE_NEW_CONSOLE', 'CREATE_NEW_PROCESS_GROUP', 'CREATE_NO_WINDOW', 'CREATE_PRESERVE_CODE_AUTHZ_LEVEL', 'CREATE_SEPARATE_WOW_VDM', 'CREATE_SHARED_WOW_VDM', 'CREATE_SUSPENDED', 'CREATE_UNICODE_ENVIRONMENT', 'DEBUG_ONLY_THIS_PROCESS', 'DEBUG_PROCESS', 'DETACHED_PROCESS', 'HIGH_PRIORITY_CLASS', 'IDLE_PRIORITY_CLASS', 'LIST_MODULES_32BIT', 'LIST_MODULES_64BIT', 'LIST_MODULES_ALL', 'LIST_MODULES_DEFAULT', 'MAXIMUM_PROCESSORS', 'NORMAL_PRIORITY_CLASS', 'REALTIME_PRIORITY_CLASS', 'STARTF_FORCEOFFFEEDBACK', 'STARTF_FORCEONFEEDBACK', 'STARTF_RUNFULLSCREEN', 'STARTF_USECOUNTCHARS', 'STARTF_USEFILLATTRIBUTE', 'STARTF_USEPOSITION', 'STARTF_USESHOWWINDOW', 'STARTF_USESIZE', 'STARTF_USESTDHANDLES', 'THREAD_MODE_BACKGROUND_BEGIN', 'THREAD_MODE_BACKGROUND_BEGIN', 'THREAD_MODE_BACKGROUND_END', 'THREAD_MODE_BACKGROUND_END', 'THREAD_PRIORITY_ABOVE_NORMAL', 'THREAD_PRIORITY_BELOW_NORMAL', 'THREAD_PRIORITY_HIGHEST', 'THREAD_PRIORITY_IDLE', 'THREAD_PRIORITY_LOWEST', 'THREAD_PRIORITY_NORMAL', 'THREAD_PRIORITY_TIME_CRITICAL']
import typing
import win32typing
"""An interface to the win32 Process and Thread API's"""


def STARTUPINFO() -> 'win32typing.PySTARTUPINFO':
    """
    Creates a new STARTUPINFO object.

Args:



Returns:

      win32typing.PySTARTUPINFO
        
    """
    pass
        

def beginthreadex(sa:'win32typing.PySECURITY_ATTRIBUTES',stackSize:'typing.Any',entryPoint:'typing.Any',args:'typing.Any',flags:'typing.Any') -> 'typing.Tuple[int, typing.Any]':
    """
    Creates a new thread

Args:

      sa(win32typing.PySECURITY_ATTRIBUTES):The security attributes, or None
      stackSize(typing.Any):Stack size for the new thread, or zero for the default size.
      entryPoint(typing.Any):The thread function.
      args(typing.Any):Args passed to the function.
      flags(typing.Any):Can be CREATE_SUSPENDED so thread doesn't run immediatelyReturn ValueThe result is a tuple of the thread handle and thread ID.

Returns:

      typing.Tuple[int, typing.Any]:Can be CREATE_SUSPENDED so thread doesn't run immediatelyReturn ValueThe result is a tuple of the thread handle and thread ID.

        
    """
    pass
        

def CreateRemoteThread(hprocess:'int',sa:'win32typing.PySECURITY_ATTRIBUTES',stackSize:'typing.Any',entryPoint:'typing.Any',Parameter:'typing.Any',flags:'typing.Any') -> 'typing.Tuple[int, typing.Any]':
    """
    creates a thread that runs in 

the virtual address space of another process.

Args:

      hprocess(int):The handle to the remote process.
      sa(win32typing.PySECURITY_ATTRIBUTES):The security attributes, or None
      stackSize(typing.Any):Stack size for the new thread, or zero for the default size.
      entryPoint(typing.Any):The thread function's address.
      Parameter(typing.Any):Arg passed to the function in the form of a void pointer
      flags(typing.Any):Return ValueThe result is a tuple of the thread handle and thread ID.

Returns:

      typing.Tuple[int, typing.Any]:Return ValueThe result is a tuple of the thread handle and thread ID.

        
    """
    pass
        

def CreateProcess(appName:'str',commandLine:'str',processAttributes:'win32typing.PySECURITY_ATTRIBUTES',threadAttributes:'win32typing.PySECURITY_ATTRIBUTES',bInheritHandles:'typing.Any',dwCreationFlags:'typing.Any',newEnvironment:'typing.Union[typing.Any]',currentDirectory:'str',startupinfo:'win32typing.PySTARTUPINFO') -> 'typing.Tuple[int, int, typing.Any, typing.Any]':
    """
    Creates a new process and its primary thread. The new process executes the specified executable file.

Args:

      appName(str):name of executable module, or None
      commandLine(str):command line string, or None
      processAttributes(win32typing.PySECURITY_ATTRIBUTES):process security attributes, or None
      threadAttributes(win32typing.PySECURITY_ATTRIBUTES):thread security attributes, or None
      bInheritHandles(typing.Any):handle inheritance flag
      dwCreationFlags(typing.Any):creation flags.  May be a combination of the following values from the win32con module:ValueMeaningCREATE_BREAKAWAY_FROM_JOBWindows 2000: The child processes of a process associated with a job are not associated with the job. If the calling process is not associated with a job, this flag has no effect. If the calling process is associated with a job, the job must set the JOB_OBJECT_LIMIT_BREAKAWAY_OK limit or CreateProcess will fail.CREATE_DEFAULT_ERROR_MODEThe new process does not inherit the error mode of the calling process. Instead, CreateProcess gives the new process the current default error mode. An application sets the current default error mode by calling SetErrorMode. This flag is particularly useful for multi-threaded shell applications that run with hard errors disabled. The default behavior for CreateProcess is for the new process to inherit the error mode of the caller. Setting this flag changes that default behavior.CREATE_FORCE_DOSWindows NT/2000: This flag is valid only when starting a 16-bit bound application. If set, the system will force the application to run as an MS-DOS-based application rather than as an OS/2-based application.CREATE_NEW_CONSOLEThe new process has a new console, instead of inheriting the parent's console. This flag cannot be used with the DETACHED_PROCESS flag.CREATE_NEW_PROCESS_GROUPThe new process is the root process of a new process group. The process group includes all processes that are descendants of this root process. The process identifier of the new process group is the same as the process identifier, which is returned in the lpProcessInformation parameter. Process groups are used by the GenerateConsoleCtrlEvent function to enable sending a CTRL+C or CTRL+BREAK signal to a group of console processes.CREATE_NO_WINDOWWindows NT/2000: This flag is valid only when starting a console application. If set, the console application is run without a console window.CREATE_SEPARATE_WOW_VDMWindows NT/2000: This flag is valid only when starting a 16-bit Windows-based application. If set, the new process runs in a private Virtual DOS Machine (VDM). By default, all 16-bit Windows-based applications run as threads in a single, shared VDM. The advantage of running separately is that a crash only terminates the single VDM; any other programs running in distinct VDMs continue to function normally. Also, 16-bit Windows-based applications that are run in separate VDMs have separate input queues. That means that if one application stops responding momentarily, applications in separate VDMs continue to receive input. The disadvantage of running separately is that it takes significantly more memory to do so. You should use this flag only if the user requests that 16-bit applications should run in them own VDM.CREATE_SHARED_WOW_VDMWindows NT/2000: The flag is valid only when starting a 16-bit Windows-based application. If the DefaultSeparateVDM switch in the Windows section of WIN.INI is TRUE, this flag causes the CreateProcess function to override the switch and run the new process in the shared Virtual DOS Machine.CREATE_SUSPENDEDThe primary thread of the new process is created in a suspended state, and does not run until the ResumeThread function is called.CREATE_UNICODE_ENVIRONMENTIndicates the format of the lpEnvironment parameter. If this flag is set, the environment block pointed to by lpEnvironment uses Unicode characters. Otherwise, the environment block uses ANSI characters.DEBUG_PROCESSIf this flag is set, the calling process is treated as a debugger, and the new process is debugged. The system notifies the debugger of all debug events that occur in the process being debugged. If you create a process with this flag set, only the calling thread (the thread that called CreateProcess) can call the WaitForDebugEvent function. Windows 95/98: This flag is not valid if the new process is a 16-bit application.DEBUG_ONLY_THIS_PROCESSIf this flag is not set and the calling process is being debugged, the new process becomes another process being debugged by the calling process's debugger. If the calling process is not a process being debugged, no debugging-related actions occur.DETACHED_PROCESSFor console processes, the new process does not have access to the console of the parent process. The new process can call the AllocConsole function at a later time to create a new console. This flag cannot be used with the CREATE_NEW_CONSOLE flag.ABOVE_NORMAL_PRIORITY_CLASSWindows 2000: Indicates a process that has priority higher than NORMAL_PRIORITY_CLASS but lower than HIGH_PRIORITY_CLASS.BELOW_NORMAL_PRIORITY_CLASSWindows 2000: Indicates a process that has priority higher than IDLE_PRIORITY_CLASS but lower than NORMAL_PRIORITY_CLASS.HIGH_PRIORITY_CLASSIndicates a process that performs time-critical tasks. The threads of a high-priority class process preempt the threads of normal-priority or idle-priority class processes. An example is the Task List, which must respond quickly when called by the user, regardless of the load on the system. Use extreme care when using the high-priority class, because a CPU-bound application with a high-priority class can use nearly all available cycles.IDLE_PRIORITY_CLASSIndicates a process whose threads run only when the system is idle and are preempted by the threads of any process running in a higher priority class. An example is a screen saver. The idle priority class is inherited by child processes.NORMAL_PRIORITY_CLASSIndicates a normal process with no special scheduling needs.REALTIME_PRIORITY_CLASSIndicates a process that has the highest possible priority. The threads of a real-time priority class process preempt the threads of all other processes, including operating system processes performing important tasks. For example, a real-time process that executes for more than a very brief interval can cause disk caches not to flush or cause the mouse to be unresponsive.
      newEnvironment(typing.Union[typing.Any]):A dictionary of string or Unicode pairs to define the environment for the process, or None to inherit the current environment.
      currentDirectory(str):current directory name, or None
      startupinfo(win32typing.PySTARTUPINFO):a STARTUPINFO object that specifies how the main window for the new process should appear.CommentsThe result is a tuple of (hProcess, hThread, dwProcessId, dwThreadId)

Returns:

      typing.Tuple[int, int, typing.Any, typing.Any]
        
    """
    pass
        

def CreateProcessAsUser(hToken:'int',appName:'str',commandLine:'str',processAttributes:'win32typing.PySECURITY_ATTRIBUTES',threadAttributes:'win32typing.PySECURITY_ATTRIBUTES',bInheritHandles:'typing.Any',dwCreationFlags:'typing.Any',newEnvironment:'typing.Any',currentDirectory:'str',startupinfo:'win32typing.PySTARTUPINFO') -> 'typing.Tuple[int, int, typing.Any, typing.Any]':
    """
    Creates a new process in the context of the specified user.

Args:

      hToken(int):Handle to a token that represents a logged-on user
      appName(str):name of executable module, or None
      commandLine(str):command line string, or None
      processAttributes(win32typing.PySECURITY_ATTRIBUTES):process security attributes, or None
      threadAttributes(win32typing.PySECURITY_ATTRIBUTES):thread security attributes, or None
      bInheritHandles(typing.Any):handle inheritance flag
      dwCreationFlags(typing.Any):creation flags
      newEnvironment(typing.Any):A dictionary of stringor Unicode pairs to define the environment for the process, or None to inherit the current environment.
      currentDirectory(str):current directory name, or None
      startupinfo(win32typing.PySTARTUPINFO):a STARTUPINFO object that specifies how the main window for the new process should appear.CommentsThe result is a tuple of (hProcess, hThread, dwProcessId, dwThreadId)

Returns:

      typing.Tuple[int, int, typing.Any, typing.Any]
        
    """
    pass
        

def GetCurrentProcess() -> 'typing.Any':
    """
    Retrieves a pseudo handle for the current process.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def GetProcessVersion(processId:'typing.Any') -> 'typing.Any':
    """
    Obtains the major and minor version numbers of the system on which a specified process expects to run.

Args:

      processId(typing.Any):identifier specifying the process of interest.

Returns:

      typing.Any
        
    """
    pass
        

def GetCurrentProcessId() -> 'typing.Any':
    """
    Retrieves the process identifier of the calling process.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def GetStartupInfo() -> 'win32typing.PySTARTUPINFO':
    """
    Retrieves the contents of the STARTUPINFO structure that was specified when the calling process was created.

Args:



Returns:

      win32typing.PySTARTUPINFO
        
    """
    pass
        

def GetPriorityClass(handle:'int') -> 'typing.Any':
    """
    None

Args:

      handle(int):handle to the thread

Returns:

      typing.Any
        
    """
    pass
        

def GetExitCodeThread(handle:'int') -> 'typing.Any':
    """
    None

Args:

      handle(int):handle to the thread

Returns:

      typing.Any
        
    """
    pass
        

def GetExitCodeProcess(handle:'int') -> 'typing.Any':
    """
    None

Args:

      handle(int):handle to the process

Returns:

      typing.Any
        
    """
    pass
        

def GetWindowThreadProcessId(hwnd:'int') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves the identifier of the thread and process that created the specified window.

Args:

      hwnd(typing.Any):handle to the windowReturn ValueThe result is a tuple of (threadId, processId)

Returns:

      typing.Tuple[typing.Any, typing.Any]:handle to the windowReturn ValueThe result is a tuple of (threadId, processId)

        
    """
    pass
        

def SetThreadPriority(handle:'int',nPriority:'typing.Any') -> 'None':
    """
    None

Args:

      handle(int):handle to the thread
      nPriority(typing.Any):thread priority level

Returns:

      None
        
    """
    pass
        

def GetThreadPriority(handle:'int') -> 'typing.Any':
    """
    None

Args:

      handle(int):handle to the thread

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessPriorityBoost(Process:'int') -> 'typing.Any':
    """
    Determines if dynamic priority adjustment is enabled for a process

Args:

      Process(int):Handle to a process

Returns:

      typing.Any
        
    """
    pass
        

def SetProcessPriorityBoost(Process:'int',DisablePriorityBoost:'typing.Any') -> 'None':
    """
    Enables or disables dynamic priority adjustment for a process

Args:

      Process(int):Handle to a process
      DisablePriorityBoost(typing.Any):True to disable or False to enable

Returns:

      None
        
    """
    pass
        

def GetThreadPriorityBoost(Thread:'int') -> 'typing.Any':
    """
    Determines if dynamic priority adjustment is enabled for a thread

Args:

      Thread(int):Handle to a thread

Returns:

      typing.Any
        
    """
    pass
        

def SetThreadPriorityBoost(Thread:'int',DisablePriorityBoost:'typing.Any') -> 'None':
    """
    Enables or disables dynamic priority adjustment for a thread

Args:

      Thread(int):Handle to a thread
      DisablePriorityBoost(typing.Any):True to disable or False to enable

Returns:

      None
        
    """
    pass
        

def GetThreadIOPendingFlag(Thread:'int') -> 'typing.Any':
    """
    Determines if thread has any outstanding IO requests

Args:

      Thread(int):Handle to a thread

Returns:

      typing.Any
        
    """
    pass
        

def GetThreadTimes(Thread:'int') -> 'typing.Any':
    """
    Returns a thread's time statistics

Args:

      Thread(int):Handle to a thread

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessId(Process:'int') -> 'typing.Any':
    """
    Returns the Pid for a process handle

Args:

      Process(int):Handle to a process

Returns:

      typing.Any
        
    """
    pass
        

def SetPriorityClass(handle:'int',dwPriorityClass:'typing.Any') -> 'None':
    """
    None

Args:

      handle(int):handle to the process
      dwPriorityClass(typing.Any):priority class value

Returns:

      None
        
    """
    pass
        

def AttachThreadInput(idAttach:'typing.Any',idAttachTo:'typing.Any',Attach:'typing.Any') -> 'None':
    """
    Attaches or detaches the input of two threads

Args:

      idAttach(typing.Any):The id of a thread
      idAttachTo(typing.Any):The id of the thread to which it will be attached
      Attach(typing.Any):Indicates whether thread should be attached or detached

Returns:

      None
        
    """
    pass
        

def SetThreadIdealProcessor(handle:'int',dwIdealProcessor:'typing.Any') -> 'typing.Any':
    """
    Used to specify a preferred processor for a thread. The system schedules threads on their preferred processors whenever possible.

Args:

      handle(int):handle to the thread of interest
      dwIdealProcessor(typing.Any):ideal processor number

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessAffinityMask(hProcess:'int') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Gets a processor affinity mask for a specified process

Args:

      hProcess(int):handle to the process of interestReturn ValueThe result is a tuple of (process affinity mask, system affinity mask)

Returns:

      typing.Tuple[typing.Any, typing.Any]:handle to the process of interestReturn ValueThe result is a tuple of (process affinity mask, system affinity mask)

        
    """
    pass
        

def SetProcessAffinityMask(hProcess:'int',mask:'typing.Any') -> 'None':
    """
    Sets a processor affinity mask for a specified process.

Args:

      hProcess(int):handle to the process of interest
      mask(typing.Any):a processor affinity maskCommentsThis function does not exist on all platforms.

Returns:

      None
        
    """
    pass
        

def SetThreadAffinityMask(hThread:'int',ThreadAffinityMask:'typing.Any') -> 'typing.Any':
    """
    Sets a processor affinity mask for a specified thread.

Args:

      hThread(int):handle to the thread of interest
      ThreadAffinityMask(typing.Any):a processor affinity mask

Returns:

      typing.Any
        
    """
    pass
        

def SuspendThread(handle:'int') -> 'typing.Any':
    """
    Suspends the specified thread.

Args:

      handle(int):handle to the threadReturn ValueThe return value is the thread's previous suspend count

Returns:

      typing.Any:handle to the threadReturn ValueThe return value is the thread's previous suspend count

        
    """
    pass
        

def ResumeThread(handle:'int') -> 'typing.Any':
    """
    Resumes the specified thread. When the suspend count is decremented to zero, the execution of the thread is resumed.

Args:

      handle(int):handle to the threadReturn ValueThe return value is the thread's previous suspend count

Returns:

      typing.Any:handle to the threadReturn ValueThe return value is the thread's previous suspend count

        
    """
    pass
        

def TerminateProcess(handle:'int',exitCode:'typing.Any') -> 'None':
    """
    Terminates the specified process and all of its threads.

Args:

      handle(int):handle to the process
      exitCode(typing.Any):The exit code for the process.

Returns:

      None
        
    """
    pass
        

def ExitProcess(exitCode:'typing.Any') -> 'None':
    """
    Ends a process and all its threads

Args:

      exitCode(typing.Any):Specifies the exit code for the process, and for all threads that are terminated as a result of this callCommentsExitProcess is the preferred method of ending a process. This function provides a clean process shutdown. This includes calling the entry-point function of all attached dynamic-link libraries (DLLs) with a value indicating that the process is detaching from the DLL. If a process terminates by calling win32process::TerminateProcess, the DLLs that the process is attached to are not notified of the process termination.

Returns:

      None
        
    """
    pass
        

def EnumProcesses() -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Returns Pids for currently running processes

Args:



Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def EnumProcessModules(hProcess:'int') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Lists loaded modules for a process handle

Args:

      hProcess(int):Process handle as returned by OpenProcess

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def EnumProcessModulesEx(hProcess:'int',FilterFlag:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Lists 32 or 64-bit modules load by a process

Args:

      hProcess(int):Process handle as returned by OpenProcess
      FilterFlag(typing.Any):Controls whether 32 or 64-bit modules are returnedCommentsRequires Vista or later

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def GetModuleFileNameEx(hProcess:'int',hModule:'int') -> 'typing.Any':
    """
    Return name of module loaded by another process (uses process handle, not pid)

Args:

      hProcess(int):Process handle as returned by OpenProcess
      hModule(int):Module handle

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessMemoryInfo(hProcess:'int') -> 'typing.Any':
    """
    Returns process memory statistics as a dict representing a PROCESS_MEMORY_COUNTERS struct

Args:

      hProcess(int):Process handle as returned by OpenProcess

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessTimes(hProcess:'int') -> 'typing.Any':
    """
    Retrieve time statics for a process by handle.  (KernelTime and UserTime in 100 nanosecond units)

Args:

      hProcess(int):Process handle as returned by OpenProcess

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessIoCounters(hProcess:'int') -> 'typing.Any':
    """
    Return I/O statistics for a process as a dictionary representing an IO_COUNTERS struct.

Args:

      hProcess(int):Process handle as returned by OpenProcess

Returns:

      typing.Any
        
    """
    pass
        

def GetProcessWindowStation() -> 'None':
    """
    Returns a handle to the window station for the calling process

Args:



Returns:

      None
        
    """
    pass
        

def GetProcessWorkingSetSize(hProcess:'int') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Returns min and max working set sizes for a process by handle

Args:

      hProcess(int):Process handle as returned by win32api::OpenProcess

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def SetProcessWorkingSetSize(hProcess:'int',MinimumWorkingSetSize:'typing.Any',MaximumWorkingSetSize:'typing.Any') -> 'None':
    """
    Sets minimum and maximum working set sizes for a process

Args:

      hProcess(int):Process handle as returned by OpenProcess
      MinimumWorkingSetSize(typing.Any):Minimum number of bytes to keep in physical memory
      MaximumWorkingSetSize(typing.Any):Maximum number of bytes to keep in physical memoryCommentsSet both min and max to -1 to have process swapped out completely

Returns:

      None
        
    """
    pass
        

def GetProcessShutdownParameters() -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves shutdown priority and flags for current process

Args:



Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def SetProcessShutdownParameters(Level:'typing.Any',Flags:'typing.Any') -> 'None':
    """
    Sets shutdown priority and flags for current process

Args:

      Level(typing.Any):Priority, higher means earlier
      Flags(typing.Any):Currently only SHUTDOWN_NORETRY validCommentsRanges are 000-0FF Reserved by windows, 100-1FF Last, 200-2FF Middle, 300-3FF First, 400-4FF Reserved by windows

Returns:

      None
        
    """
    pass
        

def GetGuiResources(Process:'int',Flags:'typing.Any') -> 'typing.Any':
    """
    Returns the number of GDI or user object handles held by a process

Args:

      Process(int):Handle to a process as returned by win32api::OpenProcess
      Flags(typing.Any):GR_GDIOBJECTS or GR_USEROBJECTS (from win32con)CommentsAvailable on Win2k and up

Returns:

      typing.Any
        
    """
    pass
        

def IsWow64Process(Process:'int'=None) -> 'typing.Any':
    """
    Determines whether the specified process is running under WOW64.

Args:

      Process(int):Handle to a process as returned by win32api::OpenProcess, win32api::GetCurrentProcess, etc, or will use the current process handle if None (the default) is passed.Return ValueIf this function is not provided by the operating system, the return value is False (ie, a NotImplemented exception will never be thrown). However, if the function exists but fails, a win32process.error exception is thrown as normal.

Returns:

      typing.Any:Handle to a process as returned by 

win32api::OpenProcess, win32api::GetCurrentProcess, etc, or 

will use the current process handle if None (the default) is passed.
Return ValueIf this function is not provided by the operating system, the 

return value is False (ie, a NotImplemented exception will never be thrown). 

However, if the function exists but fails, a win32process.error exception 

is thrown as normal.

        
    """
    pass
        
ABOVE_NORMAL_PRIORITY_CLASS = ...
BELOW_NORMAL_PRIORITY_CLASS = ...
CREATE_BREAKAWAY_FROM_JOB = ...
CREATE_DEFAULT_ERROR_MODE = ...
CREATE_NEW_CONSOLE = ...
CREATE_NEW_PROCESS_GROUP = ...
CREATE_NO_WINDOW = ...
CREATE_PRESERVE_CODE_AUTHZ_LEVEL = ...
CREATE_SEPARATE_WOW_VDM = ...
CREATE_SHARED_WOW_VDM = ...
CREATE_SUSPENDED = ...
CREATE_UNICODE_ENVIRONMENT = ...
DEBUG_ONLY_THIS_PROCESS = ...
DEBUG_PROCESS = ...
DETACHED_PROCESS = ...
HIGH_PRIORITY_CLASS = ...
IDLE_PRIORITY_CLASS = ...
LIST_MODULES_32BIT = ...
LIST_MODULES_64BIT = ...
LIST_MODULES_ALL = ...
LIST_MODULES_DEFAULT = ...
MAXIMUM_PROCESSORS = ...
NORMAL_PRIORITY_CLASS = ...
REALTIME_PRIORITY_CLASS = ...
STARTF_FORCEOFFFEEDBACK = ...
STARTF_FORCEONFEEDBACK = ...
STARTF_RUNFULLSCREEN = ...
STARTF_USECOUNTCHARS = ...
STARTF_USEFILLATTRIBUTE = ...
STARTF_USEPOSITION = ...
STARTF_USESHOWWINDOW = ...
STARTF_USESIZE = ...
STARTF_USESTDHANDLES = ...
THREAD_MODE_BACKGROUND_BEGIN = ...
THREAD_MODE_BACKGROUND_BEGIN = ...
THREAD_MODE_BACKGROUND_END = ...
THREAD_MODE_BACKGROUND_END = ...
THREAD_PRIORITY_ABOVE_NORMAL = ...
THREAD_PRIORITY_BELOW_NORMAL = ...
THREAD_PRIORITY_HIGHEST = ...
THREAD_PRIORITY_IDLE = ...
THREAD_PRIORITY_LOWEST = ...
THREAD_PRIORITY_NORMAL = ...
THREAD_PRIORITY_TIME_CRITICAL = ...



__all__=['', 'LoadPerfCounterTextStrings', 'UnloadPerfCounterTextStrings', 'CounterDefinition', 'ObjectType', 'PerfMonManager']
import typing
import win32typing
"""A module which wraps Performance Monitor functions."""


def LoadPerfCounterTextStrings() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def UnloadPerfCounterTextStrings() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def CounterDefinition() -> 'win32typing.PyPERF_COUNTER_DEFINITION':
    """
    None

Args:



Returns:

      win32typing.PyPERF_COUNTER_DEFINITION
        
    """
    pass
        

def ObjectType() -> 'win32typing.PyPERF_OBJECT_TYPE':
    """
    Creates a new PERF_OBJECT_TYPE object

Args:



Returns:

      win32typing.PyPERF_OBJECT_TYPE
        
    """
    pass
        

def PerfMonManager(serviceName:'str',seqPerfObTypes:'typing.List[win32typing.PyPERF_OBJECT_TYPE]',mappingName:'str'=None,eventSourceName:'str'=None) -> 'win32typing.PyPerfMonManager':
    """
    Creates a new PERF_OBJECT_TYPE object

Args:

      serviceName(str):The name of the service for which data is being provided.
      seqPerfObTypes(typing.List[win32typing.PyPERF_OBJECT_TYPE]):A sequence of objects to use in the performance monitor.  At this stage, len(seqPerfObTypes) must == 1.
      mappingName(str):The name of the mapping to open.  This must be the same as the DLL name providing the information.  If None, the serviceName is used.
      eventSourceName(str):The name used by the DLL for error messages in the registry.  If None, the serviceName is used.CommentsThe application need not be a service, but it must have an entry in the Services section of the registry.  This limits the performance monitor to being able to provide only one 'counter type', but still many counters within that type. See the documentation for the Performance Monitor API for more details.

Returns:

      win32typing.PyPerfMonManager
        
    """
    pass
        


__all__=['', 'CancelWaitableTimer', 'CreateEvent', 'CreateMutex', 'CreateSemaphore', 'CreateWaitableTimer', 'MsgWaitForMultipleObjects', 'MsgWaitForMultipleObjectsEx', 'OpenEvent', 'OpenMutex', 'OpenSemaphore', 'OpenWaitableTimer', 'PulseEvent', 'ReleaseMutex', 'ReleaseSemaphore', 'ResetEvent', 'SetEvent', 'SetWaitableTimer', 'WaitForMultipleObjects', 'WaitForMultipleObjectsEx', 'WaitForSingleObject', 'WaitForSingleObjectEx', 'WaitForInputIdle', 'EVENT_ALL_ACCESS', 'EVENT_MODIFY_STATE', 'INFINITE', 'MAXIMUM_WAIT_OBJECTS', 'QS_ALLEVENTS', 'QS_ALLINPUT', 'QS_HOTKEY', 'QS_INPUT', 'QS_KEY', 'QS_MOUSE', 'QS_MOUSEBUTTON', 'QS_MOUSEMOVE', 'QS_PAINT', 'QS_POSTMESSAGE', 'QS_SENDMESSAGE', 'QS_TIMER', 'SYNCHRONIZE', 'WAIT_ABANDONED', 'WAIT_ABANDONED_0', 'WAIT_FAILED', 'WAIT_IO_COMPLETION', 'WAIT_OBJECT_0', 'WAIT_TIMEOUT']
import typing
import win32typing
"""A module which provides an interface to the win32 event/wait API"""


def CancelWaitableTimer() -> 'None':
    """
    Cancels a waiting timer.

Args:



Returns:

      None
        
    """
    pass
        

def CreateEvent(EventAttributes:'win32typing.PySECURITY_ATTRIBUTES',bManualReset:'typing.Any',bInitialState:'typing.Any',Name:'str') -> 'int':
    """
    Creates a waitable event

Args:

      EventAttributes(win32typing.PySECURITY_ATTRIBUTES):The security attributes, or None
      bManualReset(typing.Any):flag for manual-reset event
      bInitialState(typing.Any):flag for initial state
      Name(str):event-object name, or NoneReturn ValueThe result is a handle to the created object

Returns:

      int:event-object name, or NoneReturn ValueThe result is a handle to the created object

        
    """
    pass
        

def CreateMutex(MutexAttributes:'win32typing.PySECURITY_ATTRIBUTES',InitialOwner:'typing.Any',Name:'str') -> 'int':
    """
    Creates a mutex

Args:

      MutexAttributes(win32typing.PySECURITY_ATTRIBUTES):Specifies inheritance and security descriptor for object, or None for defaults
      InitialOwner(typing.Any):flag for initial ownership
      Name(str):Mutex-object name, or NoneReturn ValueThe result is a handle to the created object

Returns:

      int:Mutex-object name, or NoneReturn ValueThe result is a handle to the created object

        
    """
    pass
        

def CreateSemaphore(SemaphoreAttributes:'win32typing.PySECURITY_ATTRIBUTES',InitialCount:'typing.Any',MaximumCount:'typing.Any',SemaphoreName:'typing.Any') -> 'int':
    """
    Creates a semaphore, or opens an existing one

Args:

      SemaphoreAttributes(win32typing.PySECURITY_ATTRIBUTES):Specifies inheritance and security descriptor for object, or None for defaults
      InitialCount(typing.Any):Initial count
      MaximumCount(typing.Any):Maximum count
      SemaphoreName(typing.Any):Semaphore-object name, or NoneWin32 API References

Returns:

      int:Search for CreateSemaphore at msdn, google or google groups.
Return ValueThe result is a handle to the object

        
    """
    pass
        

def CreateWaitableTimer(TimerAttributes:'win32typing.PySECURITY_ATTRIBUTES',ManualReset:'typing.Any',TimerName:'typing.Any') -> 'int':
    """
    Creates a waitable timer, or opens an existing one

Args:

      TimerAttributes(win32typing.PySECURITY_ATTRIBUTES):Specifies inheritance and security descriptor for object, or None for defaults
      ManualReset(typing.Any):True for manual reset timer, or False to create a synchronization timer
      TimerName(typing.Any):Timer object name, or NoneWin32 API References

Returns:

      int:Search for CreateWaitableTimer at msdn, google or google groups.
Return ValueThe result is a handle to the object

        
    """
    pass
        

def MsgWaitForMultipleObjects(handleList:'typing.List[int]',bWaitAll:'typing.Any',milliseconds:'typing.Any',wakeMask:'typing.Any') -> 'typing.Any':
    """
    Returns when a message arrives of an event is signalled

Args:

      handleList(typing.List[int]):A sequence of handles to wait on.
      bWaitAll(typing.Any):If true, waits for all handles in the list.
      milliseconds(typing.Any):time-out interval in milliseconds
      wakeMask(typing.Any):type of input events to wait for.  One of the win32event.QS_ constants.CommentsNote that if bWaitAll is TRUE, the function will return when there is input in the queue, and all events are signalled.  This is rarely what you want! If input is waiting, the result is win32event.WAIT_OBJECT_0+len(handles))

Returns:

      typing.Any
        
    """
    pass
        

def MsgWaitForMultipleObjectsEx(handleList:'typing.List[int]',milliseconds:'typing.Any',wakeMask:'typing.Any',waitFlags:'typing.Any') -> 'typing.Any':
    """
    Returns when a message arrives of an event is signalled

Args:

      handleList(typing.List[int]):A sequence of handles to wait on.
      milliseconds(typing.Any):time-out interval in milliseconds
      wakeMask(typing.Any):type of input events to wait for
      waitFlags(typing.Any):wait flagsCommentsThis method will no longer raise a COM E_NOTIMPL exception as it is no longer dynamically loaded.

Returns:

      typing.Any
        
    """
    pass
        

def OpenEvent(desiredAccess:'typing.Any',bInheritHandle:'typing.Any',name:'str') -> 'int':
    """
    Returns a handle of an existing named event object.

Args:

      desiredAccess(typing.Any):access flag - one of win32event::EVENT_ALL_ACCESS, win32event::EVENT_MODIFY_STATE, or (NT only) win32event::SYNCHRONIZE
      bInheritHandle(typing.Any):inherit flag
      name(str):name of event to open.

Returns:

      int
        
    """
    pass
        

def OpenMutex(desiredAccess:'typing.Any',bInheritHandle:'typing.Any',name:'str') -> 'int':
    """
    Returns a handle of an existing named mutex object.

Args:

      desiredAccess(typing.Any):access flag
      bInheritHandle(typing.Any):inherit flag
      name(str):name of mutex to open.

Returns:

      int
        
    """
    pass
        

def OpenSemaphore(desiredAccess:'typing.Any',bInheritHandle:'typing.Any',name:'str') -> 'int':
    """
    Returns a handle of an existing named semaphore object.

Args:

      desiredAccess(typing.Any):access flag
      bInheritHandle(typing.Any):inherit flag
      name(str):name of semaphore to open.

Returns:

      int
        
    """
    pass
        

def OpenWaitableTimer(desiredAccess:'typing.Any',bInheritHandle:'typing.Any',timerName:'typing.Any') -> 'int':
    """
    Opens an existing named waitable timer object

Args:

      desiredAccess(typing.Any):access flag
      bInheritHandle(typing.Any):inherit flag
      timerName(typing.Any):pointer to timer object name

Returns:

      int
        
    """
    pass
        

def PulseEvent(hEvent:'int') -> 'None':
    """
    Provides a single operation that sets (to signaled) the state of the specified event object and then resets it (to nonsignaled) after releasing the appropriate number of waiting threads.

Args:

      hEvent(int):handle of event object

Returns:

      None
        
    """
    pass
        

def ReleaseMutex(hEvent:'int') -> 'None':
    """
    Releases a mutex.

Args:

      hEvent(int):handle of mutex object

Returns:

      None
        
    """
    pass
        

def ReleaseSemaphore(hEvent:'int',lReleaseCount:'typing.Any') -> 'typing.Any':
    """
    Releases a semaphore.

Args:

      hEvent(int):handle of the semaphore object
      lReleaseCount(typing.Any):amount to add to current countReturn ValueThe result is the previous count of the semaphore.

Returns:

      typing.Any:amount to add to current countReturn ValueThe result is the previous count of the semaphore.

        
    """
    pass
        

def ResetEvent(hEvent:'int') -> 'None':
    """
    Resets an event

Args:

      hEvent(int):handle of event object

Returns:

      None
        
    """
    pass
        

def SetEvent(hEvent:'int') -> 'None':
    """
    Sets an event

Args:

      hEvent(int):handle of event object

Returns:

      None
        
    """
    pass
        

def SetWaitableTimer(handle:'int',dueTime:'typing.Any',period:'typing.Any',func:'typing.Any',param:'typing.Any',resume_state:'typing.Any') -> 'None':
    """
    Sets a waitable timer.

Args:

      handle(int):handle to timer
      dueTime(typing.Any):timer due time
      period(typing.Any):timer interval
      func(typing.Any):completion routine - must be None
      param(typing.Any):completion routine parameter - must be None
      resume_state(typing.Any):resume state

Returns:

      None
        
    """
    pass
        

def WaitForMultipleObjects(handleList:'typing.List[int]',bWaitAll:'typing.Any',milliseconds:'typing.Any') -> 'typing.Any':
    """
    Returns when an event is signalled

Args:

      handleList(typing.List[int]):A sequence of handles to wait on.
      bWaitAll(typing.Any):wait flag
      milliseconds(typing.Any):time-out interval in milliseconds

Returns:

      typing.Any
        
    """
    pass
        

def WaitForMultipleObjectsEx(handleList:'typing.List[int]',bWaitAll:'typing.Any',milliseconds:'typing.Any',bAlertable:'typing.Any') -> 'typing.Any':
    """
    Returns when an event is signalled

Args:

      handleList(typing.List[int]):A sequence of handles to wait on.
      bWaitAll(typing.Any):wait flag
      milliseconds(typing.Any):time-out interval in milliseconds
      bAlertable(typing.Any):alertable wait flag.

Returns:

      typing.Any
        
    """
    pass
        

def WaitForSingleObject(hHandle:'int',milliseconds:'typing.Any') -> 'typing.Any':
    """
    Returns when an event is signalled

Args:

      hHandle(int):handle of object to wait for
      milliseconds(typing.Any):time-out interval in millisecondsReturn ValueIf the function succeeds, the return value indicates the event that caused the function to return. This value can be one of the following.ValueMeaningWAIT_ABANDONEDThe specified object is a mutex object that was not released by the thread that owned the mutex object before the owning thread terminated. Ownership of the mutex object is granted to the calling thread, and the mutex is set to nonsignaled.WAIT_OBJECT_0The state of the specified object is signaled.WAIT_TIMEOUTThe time-out interval elapsed, and the object's state is nonsignaled.

Returns:

      typing.Any:time-out interval in millisecondsReturn ValueIf the function succeeds, the return value indicates the event that caused the function to return. This value can be one of the following.



Value


Meaning



WAIT_ABANDONEDThe specified object is a mutex object that was not released by the thread that owned the mutex object before the owning thread terminated. Ownership of the mutex object is granted to the calling thread, and the mutex is set to nonsignaled.
WAIT_OBJECT_0The state of the specified object is signaled.
WAIT_TIMEOUTThe time-out interval elapsed, and the object's state is nonsignaled.

        
    """
    pass
        

def WaitForSingleObjectEx(hHandle:'int',milliseconds:'typing.Any',bAlertable:'typing.Any') -> 'typing.Any':
    """
    Returns when an event is signalled

Args:

      hHandle(int):handle of object to wait for
      milliseconds(typing.Any):time-out interval in milliseconds
      bAlertable(typing.Any):alertable wait flag.Return ValueSee win32event::WaitForSingleObject for return values.

Returns:

      typing.Any:alertable wait flag.Return ValueSee win32event::WaitForSingleObject for return values.

        
    """
    pass
        

def WaitForInputIdle(hProcess:'int',milliseconds:'typing.Any') -> 'typing.Any':
    """
    Waits until the given process is waiting for user input with no input pending, or until the time-out interval has elapsed

Args:

      hProcess(int):handle of process to wait for
      milliseconds(typing.Any):time-out interval in millisecondsReturn ValueThe return value indicates wether the process is ready or wether it timed out. This value can be one of the following.ValueMeaning0The process is ready.WAIT_TIMEOUTThe time-out interval elapsed, and the process is not ready.

Returns:

      typing.Any:time-out interval in millisecondsReturn ValueThe return value indicates wether the process is ready or wether it timed out. This value can be one of the following.



Value


Meaning



0The process is ready.
WAIT_TIMEOUTThe time-out interval elapsed, and the process is not ready.

        
    """
    pass
        
EVENT_ALL_ACCESS = ...
EVENT_MODIFY_STATE = ...
INFINITE = ...
MAXIMUM_WAIT_OBJECTS = ...
QS_ALLEVENTS = ...
QS_ALLINPUT = ...
QS_HOTKEY = ...
QS_INPUT = ...
QS_KEY = ...
QS_MOUSE = ...
QS_MOUSEBUTTON = ...
QS_MOUSEMOVE = ...
QS_PAINT = ...
QS_POSTMESSAGE = ...
QS_SENDMESSAGE = ...
QS_TIMER = ...
SYNCHRONIZE = ...
WAIT_ABANDONED = ...
WAIT_ABANDONED_0 = ...
WAIT_FAILED = ...
WAIT_IO_COMPLETION = ...
WAIT_OBJECT_0 = ...
WAIT_TIMEOUT = ...



__all__=['', 'CoInternetCreateSecurityManager', 'CoInternetIsFeatureEnabled', 'CoInternetSetFeatureEnabled', 'FEATURE_ADDON_MANAGEMENT', 'FEATURE_BEHAVIORS', 'FEATURE_DISABLE_MK_PROTOCOL', 'FEATURE_ENTRY_COUNT', 'FEATURE_GET_URL_DOM_FILEPATH_UNENCODED', 'FEATURE_HTTP_USERNAME_PASSWORD_DISABLE', 'FEATURE_LOCALMACHINE_LOCKDOWN', 'FEATURE_MIME_HANDLING', 'FEATURE_MIME_SNIFFING', 'FEATURE_OBJECT_CACHING', 'FEATURE_PROTOCOL_LOCKDOWN', 'FEATURE_RESTRICT_ACTIVEXINSTALL', 'FEATURE_RESTRICT_FILEDOWNLOAD', 'FEATURE_SAFE_BINDTOOBJECT', 'FEATURE_SECURITYBAND', 'FEATURE_UNC_SAVEDFILECHECK', 'FEATURE_VALIDATE_NAVIGATE_URL', 'FEATURE_WEBOC_POPUPMANAGEMENT', 'FEATURE_WINDOW_RESTRICTIONS', 'FEATURE_ZONE_ELEVATION', 'GET_FEATURE_FROM_PROCESS', 'GET_FEATURE_FROM_REGISTRY', 'GET_FEATURE_FROM_THREAD', 'GET_FEATURE_FROM_THREAD_INTERNET', 'GET_FEATURE_FROM_THREAD_INTRANET', 'GET_FEATURE_FROM_THREAD_LOCALMACHINE', 'GET_FEATURE_FROM_THREAD_RESTRICTED', 'GET_FEATURE_FROM_THREAD_TRUSTED', 'SET_FEATURE_IN_REGISTRY', 'SET_FEATURE_ON_PROCESS', 'SET_FEATURE_ON_THREAD', 'SET_FEATURE_ON_THREAD_INTERNET', 'SET_FEATURE_ON_THREAD_INTRANET', 'SET_FEATURE_ON_THREAD_LOCALMACHINE', 'SET_FEATURE_ON_THREAD_RESTRICTED', 'SET_FEATURE_ON_THREAD_TRUSTED']
import typing
import win32typing
"""A module, encapsulating the ActiveX Internet interfaces"""


def CoInternetCreateSecurityManager(reserved:'typing.Any') -> 'win32typing.PyIInternetSecurityManager':
    """
    None

Args:

      reserved(typing.Any):

Returns:

      win32typing.PyIInternetSecurityManager
        
    """
    pass
        

def CoInternetIsFeatureEnabled(flags:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      flags(typing.Any):Return ValueReturns true for S_OK, False for other non-error hresults, or raises a com_error.

Returns:

      typing.Any:Return ValueReturns true for S_OK, False for other non-error hresults, or 

raises a com_error.

        
    """
    pass
        

def CoInternetSetFeatureEnabled(flags:'typing.Any',enable:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      flags(typing.Any):
      enable(typing.Any):

Returns:

      typing.Any
        
    """
    pass
        
FEATURE_ADDON_MANAGEMENT = ...
FEATURE_BEHAVIORS = ...
FEATURE_DISABLE_MK_PROTOCOL = ...
FEATURE_ENTRY_COUNT = ...
FEATURE_GET_URL_DOM_FILEPATH_UNENCODED = ...
FEATURE_HTTP_USERNAME_PASSWORD_DISABLE = ...
FEATURE_LOCALMACHINE_LOCKDOWN = ...
FEATURE_MIME_HANDLING = ...
FEATURE_MIME_SNIFFING = ...
FEATURE_OBJECT_CACHING = ...
FEATURE_PROTOCOL_LOCKDOWN = ...
FEATURE_RESTRICT_ACTIVEXINSTALL = ...
FEATURE_RESTRICT_FILEDOWNLOAD = ...
FEATURE_SAFE_BINDTOOBJECT = ...
FEATURE_SECURITYBAND = ...
FEATURE_UNC_SAVEDFILECHECK = ...
FEATURE_VALIDATE_NAVIGATE_URL = ...
FEATURE_WEBOC_POPUPMANAGEMENT = ...
FEATURE_WINDOW_RESTRICTIONS = ...
FEATURE_ZONE_ELEVATION = ...
GET_FEATURE_FROM_PROCESS = ...
GET_FEATURE_FROM_REGISTRY = ...
GET_FEATURE_FROM_THREAD = ...
GET_FEATURE_FROM_THREAD_INTERNET = ...
GET_FEATURE_FROM_THREAD_INTRANET = ...
GET_FEATURE_FROM_THREAD_LOCALMACHINE = ...
GET_FEATURE_FROM_THREAD_RESTRICTED = ...
GET_FEATURE_FROM_THREAD_TRUSTED = ...
SET_FEATURE_IN_REGISTRY = ...
SET_FEATURE_ON_PROCESS = ...
SET_FEATURE_ON_THREAD = ...
SET_FEATURE_ON_THREAD_INTERNET = ...
SET_FEATURE_ON_THREAD_INTRANET = ...
SET_FEATURE_ON_THREAD_LOCALMACHINE = ...
SET_FEATURE_ON_THREAD_RESTRICTED = ...
SET_FEATURE_ON_THREAD_TRUSTED = ...



__all__=['', 'PSGetItemPropertyHandler', 'PSGetPropertyDescription', 'PSGetPropertySystem', 'PSGetNameFromPropertyKey', 'PSGetPropertyKeyFromName', 'PSRegisterPropertySchema', 'PSUnregisterPropertySchema', 'SHGetPropertyStoreFromParsingName', 'StgSerializePropVariant', 'StgDeserializePropVariant', 'PSCreateMemoryPropertyStore', 'PSCreatePropertyStoreFromPropertySetStorage', 'PSLookupPropertyHandlerCLSID', 'SHGetPropertyStoreForWindow', 'PSGetPropertyFromPropertyStorage', 'PSGetNamedPropertyFromPropertyStorage', 'PSCreateSimplePropertyChange', 'PSCreatePropertyChangeArray', 'SHSetDefaultProperties']
import typing
import win32typing
"""A module, encapsulating the Vista Property System interfaces"""


def PSGetItemPropertyHandler(Item:'win32typing.PyIShellItem',riid:'win32typing.PyIID',ReadWrite:'typing.Any'=False) -> 'win32typing.PyIPropertyStore':
    """
    Retrieves the property store for a shell item

Args:

      Item(win32typing.PyIShellItem):A shell item
      riid(win32typing.PyIID):Interface to return
      ReadWrite(typing.Any):Pass True for a writeable property store

Returns:

      win32typing.PyIPropertyStore
        
    """
    pass
        

def PSGetPropertyDescription(Key:'win32typing.PyPROPERTYKEY',riid:'win32typing.PyIID') -> 'win32typing.PyIPropertyDescription':
    """
    Gets a description interface for a property

Args:

      Key(win32typing.PyPROPERTYKEY):A property key identifier
      riid(win32typing.PyIID):The interface to returnCommentsPossible interfaces include IPropertyDescription, IPropertyDescriptionAliasInfo, and IPropertyDescriptionSearchInfo

Returns:

      win32typing.PyIPropertyDescription
        
    """
    pass
        

def PSGetPropertySystem(riid:'win32typing.PyIID') -> 'win32typing.PyIPropertySystem':
    """
    Creates an IPropertySystem interface

Args:

      riid(win32typing.PyIID):The interface to return

Returns:

      win32typing.PyIPropertySystem
        
    """
    pass
        

def PSGetNameFromPropertyKey(Key:'win32typing.PyPROPERTYKEY') -> 'str':
    """
    Retrieves the canonical name of a property

Args:

      Key(win32typing.PyPROPERTYKEY):A property key

Returns:

      str
        
    """
    pass
        

def PSGetPropertyKeyFromName(Name:'typing.Any') -> 'win32typing.PyPROPERTYKEY':
    """
    Retrieves the property key by canonical name

Args:

      Name(typing.Any):The canonical name of a property (eg System.Author)

Returns:

      win32typing.PyPROPERTYKEY
        
    """
    pass
        

def PSRegisterPropertySchema(filename:'typing.Any') -> 'None':
    """
    Registers a group of properties described in a schema file

Args:

      filename(typing.Any):An XML file that defines a property schema (*.propdesc)

Returns:

      None
        
    """
    pass
        

def PSUnregisterPropertySchema(filename:'typing.Any') -> 'None':
    """
    Removes a property schema definition

Args:

      filename(typing.Any):A previously registered schema definition file

Returns:

      None
        
    """
    pass
        

def SHGetPropertyStoreFromParsingName(Path:'str',Flags:'typing.Any',riid:'win32typing.PyIID',BindCtx:'win32typing.PyIBindCtx'=None) -> 'win32typing.PyIPropertyStore':
    """
    Retrieves the property store for an item by 

path

Args:

      Path(str):Path to file
      Flags(typing.Any):Combination of GETPROPERTYSTOREFLAGS values (shellcon.GPS_*)
      riid(win32typing.PyIID):The interface to returnCommentsThis function does not exist on XP, even with Desktop Search installed
      BindCtx(win32typing.PyIBindCtx):Bind context, or None

Returns:

      win32typing.PyIPropertyStore
        
    """
    pass
        

def StgSerializePropVariant(propvar:'win32typing.PyPROPVARIANT') -> 'typing.Any':
    """
    None

Args:

      propvar(win32typing.PyPROPVARIANT):The value to serialize

Returns:

      typing.Any
        
    """
    pass
        

def StgDeserializePropVariant(prop:'typing.Any') -> 'win32typing.PyPROPVARIANT':
    """
    None

Args:

      prop(typing.Any):Buffer or bytes object (or str in Python 2) containing a serialized value

Returns:

      win32typing.PyPROPVARIANT
        
    """
    pass
        

def PSCreateMemoryPropertyStore(riid:'win32typing.PyIID') -> 'win32typing.PyIPropertyStore':
    """
    Creates a temporary property store that is not 

connected to any backing storage

Args:

      riid(win32typing.PyIID):The interface to createCommentsMay also be used to create PyINamedPropertyStore, PyIPropertyStoreCache, PyIPersistStream, or PyIPropertyBag

Returns:

      win32typing.PyIPropertyStore
        
    """
    pass
        

def PSCreatePropertyStoreFromPropertySetStorage(pss:'win32typing.PyIPropertySetStorage',Mode:'typing.Any',riid:'win32typing.PyIID') -> 'win32typing.PyIPropertyStore':
    """
    None

Args:

      pss(win32typing.PyIPropertySetStorage):Property container to be adapted
      Mode(typing.Any):Read or write mode, shellcon.STGM_*.  Must match mode used to open input interface.
      riid(win32typing.PyIID):The interface to createCommentsThis function does not work for the NTFS property storage implementation based on alternate data streams.

Returns:

      win32typing.PyIPropertyStore
        
    """
    pass
        

def PSLookupPropertyHandlerCLSID(FilePath:'typing.Any') -> 'win32typing.PyIID':
    """
    Returns the GUID of the property handler for a file

Args:

      FilePath(typing.Any):Name of fileCommentsIf no handler is found, the returned error code can be deceptive as it seems to indicate that the file itself was not found

Returns:

      win32typing.PyIID
        
    """
    pass
        

def SHGetPropertyStoreForWindow(hwnd:'int',riid:'win32typing.PyIID') -> 'win32typing.PyIPropertyStore':
    """
    Retrieves a collection of a window's properties

Args:

      hwnd(int):Handle to a window
      riid(win32typing.PyIID):The interface to createCommentsRequires Windows 7 or later.Return ValueThe returned store can be used to set the System.AppUserModel.ID property that determines how windows are grouped on the taskbar

Returns:

      win32typing.PyIPropertyStore:The interface to create
Comments

Requires Windows 7 or later.
Return ValueThe returned store can be used to set the System.AppUserModel.ID property that determines how windows 

are grouped on the taskbar

        
    """
    pass
        

def PSGetPropertyFromPropertyStorage(ps:'typing.Any',key:'win32typing.PyPROPERTYKEY') -> 'win32typing.PyPROPVARIANT':
    """
    Extracts a property value from a serialized 

buffer by key

Args:

      ps(typing.Any):Bytes or buffer (or str in python 2) containing a serialized property set (see PyIPersistSerializedPropStorage::GetPropertyStorage)
      key(win32typing.PyPROPERTYKEY):Property to return

Returns:

      win32typing.PyPROPVARIANT
        
    """
    pass
        

def PSGetNamedPropertyFromPropertyStorage(ps:'typing.Any',name:'typing.Any') -> 'win32typing.PyPROPVARIANT':
    """
    Extracts a property value from a serialized 

buffer by name

Args:

      ps(typing.Any):Bytes or buffer (or str in python 2) containing a serialized property set (see PyIPersistSerializedPropStorage::GetPropertyStorage)
      name(typing.Any):Property to return

Returns:

      win32typing.PyPROPVARIANT
        
    """
    pass
        

def PSCreateSimplePropertyChange(flags:'typing.Any',key:'win32typing.PyPROPERTYKEY',val:'win32typing.PyPROPVARIANT',riid:'win32typing.PyIID') -> 'win32typing.PyIPropertyChange':
    """
    None

Args:

      flags(typing.Any):The change operation, pscon.PKA_*
      key(win32typing.PyPROPERTYKEY):The property key
      val(win32typing.PyPROPVARIANT):The value that the change operation will apply
      riid(win32typing.PyIID):The interface to return.

Returns:

      win32typing.PyIPropertyChange
        
    """
    pass
        

def PSCreatePropertyChangeArray() -> 'win32typing.PyIPropertyChangeArray':
    """
    None

Args:



Returns:

      win32typing.PyIPropertyChangeArray
        
    """
    pass
        

def SHSetDefaultProperties(hwnd:'int',Item:'win32typing.PyIShellItem',FileOpFlags:'typing.Any'=0,Sink:'win32typing.PyGFileOperationProgressSink'=None) -> 'None':
    """
    Sets the default properties for a file.

Args:

      hwnd(int):Parent window for any notifications, can be None
      Item(win32typing.PyIShellItem):Shell item whose defaults are to be set
      FileOpFlags(typing.Any):File operation flags, as used with PyIFileOperation::SetOperationFlags
      Sink(win32typing.PyGFileOperationProgressSink):Event sink to receive notificationsCommentsDefault properties are registered by filetype under SetDefaultsFor value.

Returns:

      None
        
    """
    pass
        


__all__=['', 'InternetSetCookie', 'InternetGetCookie', 'InternetAttemptConnect', 'InternetCheckConnection', 'InternetGoOnline', 'InternetCloseHandle', 'InternetConnect', 'InternetOpen', 'InternetOpenUrl', 'InternetCanonicalizeUrl', 'InternetGetLastResponseInfo', 'InternetReadFile', 'InternetWriteFile', 'FtpOpenFile', 'FtpCommand', 'InternetQueryOption', 'InternetSetOption', 'FindFirstUrlCacheEntry', 'FindNextUrlCacheEntry', 'FindFirstUrlCacheEntryEx', 'FindNextUrlCacheEntryEx', 'FindCloseUrlCache', 'FindFirstUrlCacheGroup', 'FindNextUrlCacheGroup', 'GetUrlCacheEntryInfo', 'DeleteUrlCacheGroup', 'CreateUrlCacheGroup', 'CreateUrlCacheEntry', 'CommitUrlCacheEntry', 'SetUrlCacheEntryGroup', 'GetUrlCacheGroupAttribute', 'SetUrlCacheGroupAttribute', 'DeleteUrlCacheEntry']
import typing
import win32typing
"""An interface to the Windows internet (wininet) API"""


def InternetSetCookie(url:'str',lpszCookieName:'str',data:'str') -> 'None':
    """
    Creates a cookie associated with the specified URL.

Args:

      url(str):
      lpszCookieName(str):
      data(str):

Returns:

      None
        
    """
    pass
        

def InternetGetCookie(Url:'str',CookieName:'str') -> 'str':
    """
    Retrieves the cookie for the specified URL

Args:

      Url(str):Site for which to retrieve cookie
      CookieName(str):Name of cookie (documented on MSDN as not implemented)

Returns:

      str
        
    """
    pass
        

def InternetAttemptConnect(Reserved:'typing.Any'=0) -> 'None':
    """
    Attempts to make a connection to the Internet.

Args:

      Reserved(typing.Any):Use only 0.

Returns:

      None
        
    """
    pass
        

def InternetCheckConnection(Url:'str',Flags:'typing.Any'=0,Reserved:'typing.Any'=0) -> 'None':
    """
    Allows an application to check if a connection to the Internet can be established

Args:

      Url(str):Url to attempt to connect to, can be None
      Flags(typing.Any):FLAG_ICC_FORCE_CONNECTION is only defined flag
      Reserved(typing.Any):Use only 0.

Returns:

      None
        
    """
    pass
        

def InternetGoOnline(Url:'str',Parent:'typing.Any'=None,Flags:'typing.Any'=0) -> 'None':
    """
    Prompts the user for permission to initiate connection to a URL.

Args:

      Url(str):Web site to connect to
      Parent(typing.Any):Handle to parent window
      Flags(typing.Any):INTERNET_GOONLINE_REFRESH is only available flag

Returns:

      None
        
    """
    pass
        

def InternetCloseHandle(handle:'win32typing.PyHINTERNET') -> 'None':
    """
    None

Args:

      handle(win32typing.PyHINTERNET):CommentsIt should not be necessary to call this function - all handles are PyHINTERNET objects, so can have their Close method called, and will otherwise be automatically closed.

Returns:

      None
        
    """
    pass
        

def InternetConnect(Internet:'win32typing.PyHINTERNET',ServerName:'str',ServerPort:'typing.Any',Username:'str',Password:'str',Service:'typing.Any',Flags:'typing.Any',Context:'typing.Any'=None) -> 'None':
    """
    Opens an FTP, Gopher, or HTTP session for a given site.

Args:

      Internet(win32typing.PyHINTERNET):Valid HINTERNET handle returned by a previous call to win32inet::InternetOpen.
      ServerName(str):A string that contains the host name of an Internet server. Alternately, the string can contain the IP number of the site, in ASCII dotted-decimal format (for example, 11.0.1.45).
      ServerPort(typing.Any):Number of the TCP/IP port on the server to connect to. These flags set only the port that will be used. The service is set by the value of dwService. This can be one of the INTERNET_DEFAULT_*_PORT constants or INTERNET_INVALID_PORT_NUMBER, which uses the default port for the service specified by dwService.
      Username(str):A string that contains the name of the user to log on. If this parameter is	None, the function uses	an appropriate default, except	for	HTTP; a	NULL parameter in HTTP causes the server to return an error.	For	the	FTP	protocol, the default is "anonymous".
      Password(str):Address	of a null-terminated string	that contains the password to use to	log	on.	If both	Password and	Username are None, the function	uses the default "anonymous"	password. In the case of FTP, the default password is the user's e-mail name. If lpszPassword is None,	but	lpszUsername is not None, the function uses a blank password.
      Service(typing.Any):Iinteger value that contains the type	of service to access.	This can be	one	of INTERNET_SERVICE_FTP, INTERNET_SERVICE_GOPHER, or INTERNET_SERVICE_HTTP.
      Flags(typing.Any):Integer value that contains the flags specific to the	service	used. When the value of	dwService is INTERNET_SERVICE_FTP, INTERNET_FLAG_PASSIVE causes the application to	use	passive	FTP	semantics.
      Context(typing.Any):Arbitrary object to be passed to callback functionCommentsAccepts keyword args

Returns:

      None
        
    """
    pass
        

def InternetOpen(agent:'str',proxyName:'str',proxyBypass:'str',flags:'typing.Any') -> 'None':
    """
    Initializes an application's use of the Microsoft® Win32® Internet functions.

Args:

      agent(str):A string that contains the name of the application or entity calling the Internet functions. This name is used as the user agent in the HTTP protocol.
      proxyName(str):
      proxyBypass(str):
      flags(typing.Any):Combination of INTERNET_FLAG_ASYNC,INTERNET_FLAG_FROM_CACHE, or INTERNET_FLAG_OFFLINE

Returns:

      None
        
    """
    pass
        

def InternetOpenUrl(Internet:'win32typing.PyHINTERNET',Url:'str',Headers:'str'=None,Flags:'typing.Any'=0,Context:'typing.Any'=None) -> 'win32typing.PyHINTERNET':
    """
    Opens a resource specified by a 

complete FTP, Gopher, or HTTP URL.

Args:

      Internet(win32typing.PyHINTERNET):Internet handle as returned by win32inet::InternetOpen
      Url(str):A string that contains the URL to begin reading.  Only URLs beginning with ftp:, gopher:, http:, or https: are supported.
      Headers(str):a string	variable that contains the headers to be sent to the HTTP server.
      Flags(typing.Any):INTERNET_FLAG_*
      Context(typing.Any):An arbitrary object to be passed to the status callback functionCommentsAccepts keyword args.Return ValueReturns None in async mode (Internet handle created with INTERNET_FLAG_ASYNC). When handle is created, it will be passed to callback function of parent handle.

Returns:

      win32typing.PyHINTERNET:An arbitrary object to be passed to the status callback function
Comments

Accepts keyword args.
Return ValueReturns None in async mode (Internet handle created with INTERNET_FLAG_ASYNC). 

When handle is created, it will be passed to callback function of parent handle.

        
    """
    pass
        

def InternetCanonicalizeUrl(url:'str',flags:'typing.Any'=0) -> 'str':
    """
    Canonicalizes a URL, which includes 

converting unsafe characters and spaces into escape sequences.

Args:

      url(str):The URL to canonicalize.
      flags(typing.Any):integer value that contains the flags that control canonicalization. This can be one of the following values:ICU_BROWSER_MODEDoes not encode or decode characters after "#" or "?", and does not remove trailing white space after "?". If this value is not specified, the entire URL is encoded and trailing white space is removed.ICU_DECODEConverts all %XX sequences to characters, including escape sequences, before the URL is parsed.ICU_ENCODE_PERCENTEncodes any percent signs encountered. By default, percent signs are not encoded. This value is available in Microsoft® Internet Explorer 5 and later versions of the Win32® Internet functions.ICU_ENCODE_SPACES_ONLYEncodes spaces only.ICU_NO_ENCODEDoes not convert unsafe characters to escape sequences.ICU_NO_METADoes not remove meta sequences (such as "." and "..") from the URL. If no flags are specified (dwFlags = 0), the function converts all unsafe characters and meta sequences (such as .,\\ .., and ...) to escape sequences.

Returns:

      str
        
    """
    pass
        

def InternetGetLastResponseInfo() -> 'typing.Tuple[typing.Any, str]':
    """
    Retrieves the last Win32® Internet function error description or server response on the thread calling this function.

Args:



Returns:

      typing.Tuple[typing.Any, str]
        
    """
    pass
        

def InternetReadFile(hInternet:'win32typing.PyHINTERNET',size:'typing.Any') -> 'str':
    """
    None

Args:

      hInternet(win32typing.PyHINTERNET):
      size(typing.Any):Number of bytes to read.Return ValueThe result will be a string of zero bytes when the end is reached.

Returns:

      str:Number of bytes to read.Return ValueThe result will be a string of zero bytes when the end is reached.

        
    """
    pass
        

def InternetWriteFile(File:'win32typing.PyHINTERNET',Buffer:'str') -> 'typing.Any':
    """
    None

Args:

      File(win32typing.PyHINTERNET):Writeable internet	handle
      Buffer(str):String or	buffer containing data to be written

Returns:

      typing.Any
        
    """
    pass
        

def FtpOpenFile(hConnect:'win32typing.PyHINTERNET',FileName:'str',Access:'typing.Any',Flags:'typing.Any',Context:'typing.Any'=None) -> 'win32typing.PyHINTERNET':
    """
    Initiates access to a remote file on an FTP server for reading or writing.

Args:

      hConnect(win32typing.PyHINTERNET):Valid HINTERNET handle to an FTP session.
      FileName(str):The name of the file to access on the remote system.
      Access(typing.Any):Integer value that determines how the file will be accessed. This can be GENERIC_READ or GENERIC_WRITE, but not both.
      Flags(typing.Any):Integer value that contains the conditions under which the transfers occur. The application should select one transfer type and any of the flags that indicate how the caching of the file will be controlled.  The transfer type can be one of the FTP_TRANSFER_TYPE* values
      Context(typing.Any):Arbitrary object that will be passed to handle's callback functionCommentsAccepts keyword args

Returns:

      win32typing.PyHINTERNET
        
    """
    pass
        

def FtpCommand(Connect:'win32typing.PyHINTERNET',ExpectResponse:'typing.Any',Flags:'typing.Any',Command:'str',Context:'typing.Any'=None) -> 'win32typing.PyHINTERNET':
    """
    Allows an application to send commands directly to an FTP server.

Args:

      Connect(win32typing.PyHINTERNET):Valid HINTERNET	handle to an FTP session.
      ExpectResponse(typing.Any):Boolean value	that indicates whether or not the application expects a response	from the FTP server. This must be set to True if a response	is expected, or	False otherwise.
      Flags(typing.Any):Unsigned long integer value that contains the flags that control this function. This can be set to	either FTP_TRANSFER_TYPE_ASCII or FTP_TRANSFER_TYPE_BINARY
      Command(str):The command to send to the FTP server.
      Context(typing.Any):Arbitrary object	to be passed to	callbackCommentsThis function may cause a crash on 32-bit XP and Vista due to an internal error in win32inet.dll.Accepts keyword args

Returns:

      win32typing.PyHINTERNET
        
    """
    pass
        

def InternetQueryOption(hInternet:'win32typing.PyHINTERNET',Option:'typing.Any') -> 'typing.Any':
    """
    Retrieves an option for an internet handle

Args:

      hInternet(win32typing.PyHINTERNET):Internet handle, or None for global defaults
      Option(typing.Any):INTERNET_OPTION_* valueOptionReturned typeINTERNET_OPTION_CALLBACKPython callback functionINTERNET_OPTION_CONTEXT_VALUEContext objectINTERNET_OPTION_SEND_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_CONTROL_SEND_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_RECEIVE_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_CONTROL_RECEIVE_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_CODEPAGEInt - Codepage of host part of URLINTERNET_OPTION_CODEPAGE_PATHInt - Codepage for URLINTERNET_OPTION_CODEPAGE_EXTRAInt - Codepage for path part of URLINTERNET_OPTION_CONNECT_RETRIESInt - Number of time to try to reconnect to hostINTERNET_OPTION_CONNECT_TIMEOUTInt - Connection timeout in millisecondsINTERNET_OPTION_CONNECTED_STATEInt - Connection state, INTERNET_STATE_*INTERNET_OPTION_HANDLE_TYPEInt, INTERNET_HANDLE_TYPE_*INTERNET_OPTION_ERROR_MASKInt, combination of INTERNET_ERROR_MASK_*INTERNET_OPTION_EXTENDED_ERRORInt, ERROR_INTERNET_*INTERNET_OPTION_FROM_CACHE_TIMEOUTInt - Timeout in ms before cached copy is usedINTERNET_OPTION_IDNInt, INTERNET_FLAG_IDN_*INTERNET_OPTION_MAX_CONNS_PER_1_0_SERVERIntINTERNET_OPTION_MAX_CONNS_PER_SERVERIntINTERNET_OPTION_READ_BUFFER_SIZEIntINTERNET_OPTION_WRITE_BUFFER_SIZEIntINTERNET_OPTION_REQUEST_FLAGSInt, combination of INTERNET_REQFLAG_*INTERNET_OPTION_REQUEST_PRIORITYIntINTERNET_OPTION_SECURITY_FLAGSInt, SECURITY_FLAG_*INTERNET_OPTION_SECURITY_KEY_BITNESSIntINTERNET_OPTION_BYPASS_EDITED_ENTRYBooleanINTERNET_OPTION_HTTP_DECODINGBooleanINTERNET_OPTION_IGNORE_OFFLINEBooleanINTERNET_OPTION_DATAFILE_NAMEString - Name of internet cache fileINTERNET_OPTION_USERNAMEString - Username passed to InternetConnectINTERNET_OPTION_PASSWORDString - Password passed to InternetConnectINTERNET_OPTION_PROXY_PASSWORDStringINTERNET_OPTION_PROXY_USERNAMEStringINTERNET_OPTION_SECONDARY_CACHE_KEYStringINTERNET_OPTION_SECURITY_CERTIFICATEStringINTERNET_OPTION_URLStringINTERNET_OPTION_USER_AGENTStringINTERNET_OPTION_CACHE_TIMESTAMPSdict - Expiration and last modified timesINTERNET_OPTION_HTTP_VERSIONdict - HTTP_VERSION_INFOINTERNET_OPTION_VERSIONdict - INTERNET_VERSION_INFOINTERNET_OPTION_PARENT_HANDLEPyHINTERNETINTERNET_OPTION_PROXYdict - INTERNET_PROXY_INFOINTERNET_OPTION_DIAGNOSTIC_SOCKET_INFONot yet supported (INTERNET_DIAGNOSTIC_SOCKET_INFO)INTERNET_OPTION_PER_CONNECTION_OPTIONNot yet supported (INTERNET_PER_CONN_OPTION_LIST)INTERNET_OPTION_SECURITY_CERTIFICATE_STRUCTNot yet supported (INTERNET_CERTIFICATE_INFO)INTERNET_OPTION_ALTER_IDENTITYNot supportedINTERNET_OPTION_ASYNCNot supportedINTERNET_OPTION_ASYNC_IDNot supportedINTERNET_OPTION_ASYNC_PRIORITYNot supportedINTERNET_OPTION_CACHE_STREAM_HANDLENot supportedINTERNET_OPTION_CALLBACK_FILTERNot supportedINTERNET_OPTION_CLIENT_CERT_CONTEXTNot supportedINTERNET_OPTION_DATA_RECEIVE_TIMEOUTNot supportedINTERNET_OPTION_DATA_SEND_TIMEOUTNot supportedINTERNET_OPTION_CONNECT_BACKOFFNot supportedINTERNET_OPTION_CONNECT_TIMENot supportedINTERNET_OPTION_DISABLE_AUTODIALNot supportedINTERNET_OPTION_DISCONNECTED_TIMEOUTNot supportedINTERNET_OPTION_IDENTITYNot supportedINTERNET_OPTION_IDLE_STATENot supportedINTERNET_OPTION_KEEP_CONNECTIONNot supportedINTERNET_OPTION_LISTEN_TIMEOUTNot supportedINTERNET_OPTION_OFFLINE_MODENot supportedINTERNET_OPTION_OFFLINE_SEMANTICSNot supportedINTERNET_OPTION_POLICYNot supportedINTERNET_OPTION_RECEIVE_THROUGHPUTNot supportedINTERNET_OPTION_REMOVE_IDENTITYNot supportedINTERNET_OPTION_SEND_THROUGHPUTNot supportedINTERNET_OPTION_DATAFILE_EXTOnly valid for InternetSetOptionINTERNET_OPTION_DIGEST_AUTH_UNLOADOnly valid for InternetSetOptionINTERNET_OPTION_END_BROWSER_SESSIONOnly valid for InternetSetOptionINTERNET_OPTION_REFRESHOnly valid for InternetSetOptionINTERNET_OPTION_RESET_URLCACHE_SESSIONOnly valid for InternetSetOptionINTERNET_OPTION_SETTINGS_CHANGEDOnly valid for InternetSetOptionWin32 API References

Returns:

      typing.Any:Search for InternetQueryOption at msdn, google or google groups.
Return ValueThe type of object returned is dependent on the option requested

        
    """
    pass
        

def InternetSetOption(hInternet:'win32typing.PyHINTERNET',Option:'typing.Any',Buffer:'typing.Any') -> 'None':
    """
    Sets an option for an internet handle

Args:

      hInternet(win32typing.PyHINTERNET):Internet handle, or None for global defaults
      Option(typing.Any):The option to set, INTERNET_OPTION_*
      Buffer(typing.Any):Type is dependent on OptionOptionType of input objectINTERNET_OPTION_CALLBACKPython function called on status changeINTERNET_OPTION_CONTEXT_VALUEAny Python object to be passed to callback functionINTERNET_OPTION_SEND_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_CONTROL_SEND_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_RECEIVE_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_CONTROL_RECEIVE_TIMEOUTInt - timeout in millsecondsINTERNET_OPTION_CODEPAGEInt - Codepage of host part of URLINTERNET_OPTION_CODEPAGE_PATHCodepage for URLINTERNET_OPTION_CODEPAGE_EXTRAInt - Codepage for path part of URLINTERNET_OPTION_CONNECT_RETRIESInt - Number of time to try to reconnect to hostINTERNET_OPTION_CONNECT_TIMEOUTInt - Connection timeout in millisecondsINTERNET_OPTION_CONNECTED_STATEInt - Connection state, INTERNET_STATE_*INTERNET_OPTION_ERROR_MASKInt, combination of INTERNET_ERROR_MASK_*INTERNET_OPTION_FROM_CACHE_TIMEOUTInt - Timeout in ms before cached copy is usedINTERNET_OPTION_IDNInt, INTERNET_FLAG_IDN_*INTERNET_OPTION_MAX_CONNS_PER_1_0_SERVERIntINTERNET_OPTION_MAX_CONNS_PER_SERVERIntINTERNET_OPTION_READ_BUFFER_SIZEIntINTERNET_OPTION_WRITE_BUFFER_SIZEIntINTERNET_OPTION_REQUEST_PRIORITYIntINTERNET_OPTION_DIGEST_AUTH_UNLOADNoneINTERNET_OPTION_END_BROWSER_SESSIONNoneINTERNET_OPTION_REFRESHNoneINTERNET_OPTION_RESET_URLCACHE_SESSIONNoneINTERNET_OPTION_SETTINGS_CHANGEDNoneINTERNET_OPTION_BYPASS_EDITED_ENTRYBooleanINTERNET_OPTION_HTTP_DECODINGBooleanINTERNET_OPTION_IGNORE_OFFLINEBooleanINTERNET_OPTION_USERNAMEString - Username passed to InternetConnectINTERNET_OPTION_PASSWORDString - Password passed to InternetConnectINTERNET_OPTION_PROXY_PASSWORDStringINTERNET_OPTION_PROXY_USERNAMEStringINTERNET_OPTION_SECONDARY_CACHE_KEYStringINTERNET_OPTION_USER_AGENTStringINTERNET_OPTION_DATAFILE_EXTString - Extension to use for download cache fileINTERNET_OPTION_PROXYDict representing INTERNET_PROXY_INFO structINTERNET_OPTION_HTTP_VERSIONNot yet supported - HTTP_VERSION_INFOINTERNET_OPTION_PER_CONNECTION_OPTIONNot yet supported (INTERNET_PER_CONN_OPTION_LIST)INTERNET_OPTION_ALTER_IDENTITYNot supportedINTERNET_OPTION_ASYNCNot supportedINTERNET_OPTION_ASYNC_IDNot supportedINTERNET_OPTION_ASYNC_PRIORITYNot supportedINTERNET_OPTION_CACHE_STREAM_HANDLENot supportedINTERNET_OPTION_CALLBACK_FILTERNot supportedINTERNET_OPTION_CLIENT_CERT_CONTEXTNot supportedINTERNET_OPTION_DATA_RECEIVE_TIMEOUTNot supportedINTERNET_OPTION_DATA_SEND_TIMEOUTNot supportedINTERNET_OPTION_CONNECT_BACKOFFNot supportedINTERNET_OPTION_CONNECT_TIMENot supportedINTERNET_OPTION_DISABLE_AUTODIALNot supportedINTERNET_OPTION_DISCONNECTED_TIMEOUTNot supportedINTERNET_OPTION_IDENTITYNot supportedINTERNET_OPTION_IDLE_STATENot supportedINTERNET_OPTION_KEEP_CONNECTIONNot supportedINTERNET_OPTION_LISTEN_TIMEOUTNot supportedINTERNET_OPTION_OFFLINE_MODENot supportedINTERNET_OPTION_OFFLINE_SEMANTICSNot supportedINTERNET_OPTION_POLICYNot supportedINTERNET_OPTION_RECEIVE_THROUGHPUTNot supportedINTERNET_OPTION_REMOVE_IDENTITYNot supportedINTERNET_OPTION_SEND_THROUGHPUTNot supportedINTERNET_OPTION_CACHE_TIMESTAMPSOnly valid for InternetQueryOptionINTERNET_OPTION_HANDLE_TYPEOnly valid for InternetQueryOptionINTERNET_OPTION_DATAFILE_NAMEOnly valid for InternetQueryOptionINTERNET_OPTION_PARENT_HANDLEOnly valid for InternetQueryOptionINTERNET_OPTION_SECURITY_CERTIFICATEOnly valid for InternetQueryOptionINTERNET_OPTION_SECURITY_CERTIFICATE_STRUCTOnly valid for InternetQueryOptionINTERNET_OPTION_SECURITY_FLAGSOnly valid for InternetQueryOptionINTERNET_OPTION_SECURITY_KEY_BITNESSOnly valid for InternetQueryOptionINTERNET_OPTION_DIAGNOSTIC_SOCKET_INFOOnly valid for InternetQueryOptionINTERNET_OPTION_VERSIONOnly valid for InternetQueryOptionINTERNET_OPTION_EXTENDED_ERROROnly valid for InternetQueryOptionINTERNET_OPTION_REQUEST_FLAGSOnly valid for InternetQueryOptionINTERNET_OPTION_URLOnly valid for InternetQueryOptionWin32 API References

Returns:

      None
        
    """
    pass
        

def FindFirstUrlCacheEntry(SearchPattern:'typing.Any'=None) -> 'typing.Tuple[win32typing.PyUrlCacheHANDLE, typing.Any]':
    """
    Initiates an enumeration of the browser cache

Args:

      SearchPattern(typing.Any):Type of entry to find, can be 'visited:', 'cookie:', or NoneCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Tuple[win32typing.PyUrlCacheHANDLE, typing.Any]:Search for FindFirstUrlCacheEntry at msdn, google or google groups.
Return ValueReturns a handle that can be passed to win32inet::FindNextUrlCacheEntry, and a dict 

containing information for the first entry found.  Throws error code ERROR_NO_MORE_ITEMS 

if no items are found.

        
    """
    pass
        

def FindNextUrlCacheEntry(EnumHandle:'win32typing.PyUrlCacheHANDLE') -> 'typing.Any':
    """
    Continues enumeration of cached files

Args:

      EnumHandle(win32typing.PyUrlCacheHANDLE):Cache enumeration handle as returned by win32inet::FindFirstUrlCacheEntryCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any:Search for FindNextUrlCacheEntry at msdn, google or google groups.
Return ValueReturns a dict representing a INTERNET_CACHE_ENTRY_INFO strunct

        
    """
    pass
        

def FindFirstUrlCacheEntryEx(SearchPattern:'typing.Any'=None,Flags:'typing.Any'=0,Filter:'typing.Any'=0,GroupId:'typing.Any'=0) -> 'typing.Tuple[win32typing.PyUrlCacheHANDLE, typing.Any]':
    """
    Initiates an enumeration of the browser cache

Args:

      SearchPattern(typing.Any):Type of entry to find, can be 'visited:', 'cookie:', or None
      Flags(typing.Any):None currently defined
      Filter(typing.Any):Types of entries to return, combination of *_CACHE_ENTRY values
      GroupId(typing.Any):Cache group to enumerate, use 0 for allCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Tuple[win32typing.PyUrlCacheHANDLE, typing.Any]:Search for FindFirstUrlCacheEntryEx at msdn, google or google groups.
Return ValueReturns a handle that can be passed to win32inet::FindNextUrlCacheEntry, and a dict 

containing information for the first entry found.  Throws error code ERROR_NO_MORE_ITEMS 

if no items are found.

        
    """
    pass
        

def FindNextUrlCacheEntryEx(EnumHandle:'win32typing.PyUrlCacheHANDLE') -> 'typing.Any':
    """
    Continues enumeration of cached files

Args:

      EnumHandle(win32typing.PyUrlCacheHANDLE):Cache enumeration handle as returned by win32inet::FindFirstUrlCacheEntryExCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any:Search for FindNextUrlCacheEntryEx at msdn, google or google groups.
Return ValueReturns a dict representing a INTERNET_CACHE_ENTRY_INFO strunct

        
    """
    pass
        

def FindCloseUrlCache(EnumHandle:'win32typing.PyUrlCacheHANDLE') -> 'None':
    """
    Closes a cache enumeration handle

Args:

      EnumHandle(win32typing.PyUrlCacheHANDLE):Cache enumeration handle as returned by win32inet::FindFirstUrlCacheEntryCommentsAccepts keyword argsWin32 API References

Returns:

      None
        
    """
    pass
        

def FindFirstUrlCacheGroup(Filter:'typing.Any') -> 'typing.Tuple[win32typing.PyUrlCacheHANDLE, typing.Any]':
    """
    Initiates enumeration of Url cache groups

Args:

      Filter(typing.Any):CACHEGROUP_SEARCH_*CommentsAccepts keyword argsWin32 API References

Returns:

      typing.Tuple[win32typing.PyUrlCacheHANDLE, typing.Any]:Search for FindFirstUrlCacheGroup at msdn, google or google groups.
Return ValueReturns a handle that can be passed to win32inet::FindNextUrlCacheGroup, and the id 

of the first group found.

        
    """
    pass
        

def FindNextUrlCacheGroup(Find:'int') -> 'typing.Any':
    """
    Continues enumeration of cache groups

Args:

      Find(int):Group enumeration handle as returned by win32inet::FindFirstUrlCacheGroupCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def GetUrlCacheEntryInfo(UrlName:'typing.Any') -> 'typing.Any':
    """
    Retrieves cache info for a URL

Args:

      UrlName(typing.Any):Cache enumeration handle as returned by win32inet::FindFirstUrlCacheEntryCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any:Search for GetUrlCacheEntryInfo at msdn, google or google groups.
Return ValueReturns a dict representing a INTERNET_CACHE_ENTRY_INFO strunct

        
    """
    pass
        

def DeleteUrlCacheGroup(GroupId:'typing.Any',Attributes:'typing.Any') -> 'None':
    """
    Deletes a cache group

Args:

      GroupId(typing.Any):Group id
      Attributes(typing.Any):Combination of CACHEGROUP_FLAG_* flagsCommentsAccepts keyword argsWin32 API References

Returns:

      None
        
    """
    pass
        

def CreateUrlCacheGroup(Flags:'typing.Any'=0) -> 'typing.Any':
    """
    Creates a new cache group

Args:

      Flags(typing.Any):Combination of CACHEGROUP_FLAG_* flagsCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def CreateUrlCacheEntry(UrlName:'typing.Any',ExpectedFileSize:'typing.Any',FileExtension:'typing.Any') -> 'typing.Any':
    """
    Creates a cache entry for a URL

Args:

      UrlName(typing.Any):The Url for which to create an entry
      ExpectedFileSize(typing.Any):Size of content, use 0 if unknown
      FileExtension(typing.Any):Extension to use for filenameCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any:Search for CreateUrlCacheEntry at msdn, google or google groups.
Return ValueReturns the filename to which content should be written

        
    """
    pass
        

def CommitUrlCacheEntry(UrlName:'typing.Any',LocalFileName:'typing.Any',CacheEntryType:'typing.Any',ExpireTime:'win32typing.PyTime'=None,LastModifiedTime:'win32typing.PyTime'=None,HeaderInfo:'typing.Any'=None,OriginalUrl:'typing.Any'=None) -> 'typing.Any':
    """
    Commits a cache entry

Args:

      UrlName(typing.Any):The Url for which to create an entry
      LocalFileName(typing.Any):Filename returned from win32inet::CreateUrlCacheEntry. Can be None when creating a history entry.
      CacheEntryType(typing.Any):Combination of *_CACHE_ENTRY flags
      ExpireTime(win32typing.PyTime):Time at which entry expires
      LastModifiedTime(win32typing.PyTime):Modification time of URL
      HeaderInfo(typing.Any):Header data used to request Url
      OriginalUrl(typing.Any):If redirected, original site requestedCommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def SetUrlCacheEntryGroup(UrlName:'typing.Any',Flags:'typing.Any',GroupId:'typing.Any') -> 'None':
    """
    Associates a cache entry with a group

Args:

      UrlName(typing.Any):Url whose cache is to be added to the group
      Flags(typing.Any):INTERNET_CACHE_GROUP_ADD or INTERNET_CACHE_GROUP_REMOVE
      GroupId(typing.Any):Id of a cache groupCommentsAccepts keyword argsWin32 API References

Returns:

      None
        
    """
    pass
        

def GetUrlCacheGroupAttribute(GroupId:'typing.Any',Attributes:'typing.Any') -> 'typing.Any':
    """
    Retrieves attributes for a cache group

Args:

      GroupId(typing.Any):Group id
      Attributes(typing.Any):Attributes to retrieve, CACHEGROUP_ATTRIBUTE_*CommentsAccepts keyword argsWin32 API References

Returns:

      typing.Any:Search for GetUrlCacheGroupAttribute at msdn, google or google groups.
Return ValueReturns a dict representing a INTERNET_CACHE_GROUP_INFO struct

        
    """
    pass
        

def SetUrlCacheGroupAttribute(GroupId:'typing.Any',Attributes:'typing.Any',GroupInfo:'typing.Any',Flags:'typing.Any'=0) -> 'None':
    """
    Changes the attributes of a cache group

Args:

      GroupId(typing.Any):Id of a cache group
      Attributes(typing.Any):Bitmask of CACHEGROUP_ATTRIBUTE_* flags indicating which attributes to set
      GroupInfo(typing.Any):INTERNET_CACHE_GROUP_INFO dict as returned by win32inet::GetUrlCacheGroupAttribute
      Flags(typing.Any):Reserved, use 0CommentsAccepts keyword argsWin32 API References

Returns:

      None
        
    """
    pass
        

def DeleteUrlCacheEntry(UrlName:'typing.Any') -> 'None':
    """
    Deletes the cache entry for a URL

Args:

      UrlName(typing.Any):Cached url to be deleted

Returns:

      None
        
    """
    pass
        


__all__=['', 'GetExpandedName', 'Close', 'Copy', 'Init', 'OpenFile']
import typing
import win32typing
"""A module encapsulating the Windows LZ compression routines."""


def GetExpandedName(Source:'typing.Any') -> 'str':
    """
    Retrieves the original name of an expanded file,

Args:

      Source(typing.Any):Name of a compressed fileWin32 API References

Returns:

      str
        
    """
    pass
        

def Close(handle:'typing.Any') -> 'None':
    """
    Closes a handle to an LZ file.

Args:

      handle(typing.Any):The handle of the LZ file to close.Win32 API References

Returns:

      None
        
    """
    pass
        

def Copy(hSrc:'typing.Any',hDest:'typing.Any') -> 'typing.Any':
    """
    Copies a source file to a destination file.

Args:

      hSrc(typing.Any):The handle of the source file to copy.
      hDest(typing.Any):The handle of the destination file.CommentsIf the source file is compressed with the Microsoft File Compression Utility (COMPRESS.EXE), this function creates a decompressed destination file. If the source file is not compressed, this function duplicates the original file.Win32 API References

Returns:

      typing.Any
        
    """
    pass
        

def Init(handle:'typing.Any') -> 'None':
    """
    Allocates memory for the internal data structures required to decompress files, and then 

creates and initializes them.

Args:

      handle(typing.Any):handle of source fileWin32 API References

Returns:

      None
        
    """
    pass
        

def OpenFile(fileName:'str',action:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Creates, opens, reopens, or deletes the specified file.

Args:

      fileName(str):Name of file to open
      action(typing.Any):Can be one of the wi32con.OF_ constants (OF_CREATE, OF_DELETE, etc)Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        


__all__=['', 'HrInstallService', 'HrInstallMailboxAgent', 'HrCreateMailboxAgentProfile', 'HrCreateGatewayProfile', 'HrMailboxAgentExists', 'HrAdminProgramExists', 'HrRemoveMailboxAgent', 'HrRemoveProfile', 'HrEnumOrganizations', 'HrEnumSites', 'HrEnumContainers', 'HrEnumSiteAdmins', 'HrGetServiceAccountName']
import typing
import win32typing
"""An COM interface to Exchange's DAPI"""


def HrInstallService() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def HrInstallMailboxAgent() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def HrCreateMailboxAgentProfile(serviceName:'str',profile:'str') -> 'None':
    """
    None

Args:

      serviceName(str):The name of the service.
      profile(str):The profile.

Returns:

      None
        
    """
    pass
        

def HrCreateGatewayProfile(serviceName:'str',profile:'str') -> 'None':
    """
    None

Args:

      serviceName(str):The name of the service.
      profile(str):The profile.

Returns:

      None
        
    """
    pass
        

def HrMailboxAgentExists(server:'str',siteDN:'str',rdn:'str') -> 'None':
    """
    None

Args:

      server(str):The name of the server
      siteDN(str):Contains the distinguished name (DN) of the site.
      rdn(str):RDN of the site where the mailbox agent might exist.

Returns:

      None
        
    """
    pass
        

def HrAdminProgramExists() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def HrRemoveMailboxAgent(server:'str',siteDN:'str',rdn:'str') -> 'None':
    """
    Removes a Mailbox Agent

Args:

      server(str):The name of the server
      siteDN(str):Contains the distinguished name (DN) of the site.
      rdn(str):RDN of the site where the mailbox agent exists.

Returns:

      None
        
    """
    pass
        

def HrRemoveProfile(profile:'str') -> 'None':
    """
    Removes a profile

Args:

      profile(str):The profile to delete.

Returns:

      None
        
    """
    pass
        

def HrEnumOrganizations(rootDN:'str',server:'str') -> 'typing.List[str]':
    """
    Lists the names of the organizations on the server.

Args:

      rootDN(str):Contains the distinguished name (DN) of the directory information tree (DIT) root.
      server(str):The name of the server

Returns:

      typing.List[str]
        
    """
    pass
        

def HrEnumSites(server:'str',organizationDN:'str') -> 'typing.List[str]':
    """
    Lists the names of the sites in an organization.

Args:

      server(str):The name of the server
      organizationDN(str):Contains the distinguished name (DN) of the organization.

Returns:

      typing.List[str]
        
    """
    pass
        

def HrEnumContainers(server:'str',siteDN:'str',fSubtree:'typing.Any') -> 'typing.List[str]':
    """
    Lists the names of the containers on the server

Args:

      server(str):The name of the server
      siteDN(str):Distinguished name (DN) of the site.
      fSubtree(typing.Any):

Returns:

      typing.List[str]
        
    """
    pass
        

def HrEnumSiteAdmins(server:'str',siteDN:'str') -> 'typing.List[str]':
    """
    Lists the administrators for a site.

Args:

      server(str):The name of the server
      siteDN(str):Distinguished name (DN) of the site.

Returns:

      typing.List[str]
        
    """
    pass
        

def HrGetServiceAccountName(serviceName:'str',serviceName1:'str') -> 'str':
    """
    Obtains the account name for a service.

Args:

      serviceName(str):The name of the service
      serviceName1(str):The name of the service

Returns:

      str
        
    """
    pass
        


__all__=['', 'CeRapiInit', 'CeRapiUninit', 'CreateProcess', 'CeRapiInitEx', 'CeCopyFile', 'CeCheckPassword', 'CeCreateFile', 'CeDeleteFile', 'CeMoveFile', 'CeCreateDirectory', 'CeRemoveDirectory', 'CeGetTempPath', 'CeGetSystemInfo', 'CeGetDesktopDeviceCaps', 'CeGetSystemMetrics', 'CeGetSpecialFolderPath', 'CeGetStoreInformation', 'CeGetSystemPowerStatusEx', 'CeSHCreateShortcut', 'CeSHGetShortcutTarget', 'CeGetVersionEx', 'CeGlobalMemoryStatus', 'FindFiles', 'CeGetFileAttributes', 'CeSetFileAttributes', 'CeGetFileSize', 'CeReadFile', 'WriteFile', 'CSIDL_BITBUCKET', 'CSIDL_COMMON_DESKTOPDIRECTORY', 'CSIDL_COMMON_PROGRAMS', 'CSIDL_COMMON_STARTMENU', 'CSIDL_COMMON_STARTUP', 'CSIDL_CONTROLS', 'CSIDL_DESKTOP', 'CSIDL_DESKTOPDIRECTORY', 'CSIDL_DRIVES', 'CSIDL_FONTS', 'CSIDL_NETHOOD', 'CSIDL_NETWORK', 'CSIDL_PERSONAL', 'CSIDL_PRINTERS', 'CSIDL_PROGRAMS', 'CSIDL_RECENT', 'CSIDL_SENDTO', 'CSIDL_STARTMENU', 'CSIDL_STARTUP', 'CSIDL_TEMPLATES']
import typing
import win32typing
"""A module which provides an interface to the win32 CE Remote API"""


def CeRapiInit() -> 'None':
    """
    Initializes the remote API.

Args:



Returns:

      None
        
    """
    pass
        

def CeRapiUninit() -> 'None':
    """
    UnInitializes the remote API.

Args:



Returns:

      None
        
    """
    pass
        

def CreateProcess(appName:'str',commandLine:'str',processAttributes:'win32typing.PySECURITY_ATTRIBUTES',threadAttributes:'win32typing.PySECURITY_ATTRIBUTES',bInheritHandles:'typing.Any',dwCreationFlags:'typing.Any',newEnvironment:'typing.Any',currentDirectory:'str',startupinfo:'win32typing.PySTARTUPINFO') -> 'typing.Tuple[int, int, typing.Any, typing.Any]':
    """
    Creates a new process and its primary thread. The new process executes the specified executable file.

Args:

      appName(str):name of executable module, or None
      commandLine(str):command line string, or None
      processAttributes(win32typing.PySECURITY_ATTRIBUTES):process security attributes, or None
      threadAttributes(win32typing.PySECURITY_ATTRIBUTES):thread security attributes, or None
      bInheritHandles(typing.Any):handle inheritance flag
      dwCreationFlags(typing.Any):creation flags
      newEnvironment(typing.Any):A dictionary of stringor Unicode pairs to define the environment for the process, or None to inherit the current environment.
      currentDirectory(str):current directory name, or None
      startupinfo(win32typing.PySTARTUPINFO):a STARTUPINFO object that specifies how the main window for the new process should appear.CommentsThe result is a tuple of (hProcess, hThread, dwProcessId, dwThreadId)

Returns:

      typing.Tuple[int, int, typing.Any, typing.Any]
        
    """
    pass
        

def CeRapiInitEx() -> 'typing.Any':
    """
    Initializes the remote API asynchronously.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CeCopyFile(_from:'str',to:'str',bFailIfExists:'typing.Any') -> 'None':
    """
    Copies a file

Args:

      _from(str):The name of the file to copy from
      to(str):The name of the file to copy to
      bFailIfExists(typing.Any):Indicates if the operation should fail if the file exists.

Returns:

      None
        
    """
    pass
        

def CeCheckPassword(password:'str') -> 'None':
    """
    This function compares a specified string to the system password.

Args:

      password(str):The password to compare.

Returns:

      None
        
    """
    pass
        

def CeCreateFile(fileName:'str',desiredAccess:'typing.Any',shareMode:'typing.Any',attributes:'win32typing.PySECURITY_ATTRIBUTES',creationDisposition:'typing.Any',flagsAndAttributes:'typing.Any',hTemplateFile:'int') -> 'win32typing.PyCEHANDLE':
    """
    Creates or opens the a file or other object and returns a handle that can be used to access the object.

Args:

      fileName(str):The name of the file
      desiredAccess(typing.Any):access (read-write) mode Specifies the type of access to the object. An application can obtain read access, write access, read-write access, or device query access. This parameter can be any combination of the following values.ValueMeaning0Specifies device query access to the object. An application can query device attributes without accessing the device.GENERIC_READSpecifies read access to the object. Data can be read from the file and the file pointer can be moved. Combine with GENERIC_WRITE for read-write access.GENERIC_WRITESpecifies write access to the object. Data can be written to the file and the file pointer can be moved. Combine with GENERIC_READ for read-write access.
      shareMode(typing.Any):Set of bit flags that specifies how the object can be shared. If dwShareMode is 0, the object cannot be shared. Subsequent open operations on the object will fail, until the handle is closed. To share the object, use a combination of one or more of the following values:ValueMeaningFILE_SHARE_DELETEWindows NT: Subsequent open operations on the object will succeed only if delete access is requested.FILE_SHARE_READSubsequent open operations on the object will succeed only if read access is requested.FILE_SHARE_WRITESubsequent open operations on the object will succeed only if write access is requested.
      attributes(win32typing.PySECURITY_ATTRIBUTES):The security attributes, or None
      creationDisposition(typing.Any):Specifies which action to take on files that exist, and which action to take when files do not exist. For more information about this parameter, see the Remarks section. This parameter must be one of the following values:ValueMeaningCREATE_NEWCreates a new file. The function fails if the specified file already exists.CREATE_ALWAYSCreates a new file. If the file exists, the function overwrites the file and clears the existing attributes.OPEN_EXISTINGOpens the file. The function fails if the file does not exist. See the Remarks section for a discussion of why you should use the OPEN_EXISTING flag if you are using the CreateFile function for devices, including the console.OPEN_ALWAYSOpens the file, if it exists. If the file does not exist, the function creates the file as if dwCreationDisposition were CREATE_NEW.TRUNCATE_EXISTINGOpens the file. Once opened, the file is truncated so that its size is zero bytes. The calling process must open the file with at least GENERIC_WRITE access. The function fails if the file does not exist.
      flagsAndAttributes(typing.Any):file attributes
      hTemplateFile(int):Specifies a handle with GENERIC_READ access to a template file. The template file supplies file attributes and extended attributes for the file being created.   Under Win95, this must be 0, else an exception will be raised.CommentsThe following objects can be opened:filespipesmailslotscommunications resourcesdisk devices (Windows NT only)consolesdirectories (open only)

Returns:

      win32typing.PyCEHANDLE
        
    """
    pass
        

def CeDeleteFile(fileName:'str') -> 'None':
    """
    Deletes a file.

Args:

      fileName(str):The filename to delete

Returns:

      None
        
    """
    pass
        

def CeMoveFile(existingFileName:'str',newFileName:'str') -> 'None':
    """
    Renames an existing file or a directory (including all its children).

Args:

      existingFileName(str):Name of the existing file
      newFileName(str):New name for the file

Returns:

      None
        
    """
    pass
        

def CeCreateDirectory(name:'str',sa:'win32typing.PySECURITY_ATTRIBUTES') -> 'None':
    """
    Creates a directory

Args:

      name(str):The name of the directory to create
      sa(win32typing.PySECURITY_ATTRIBUTES):The security attributes, or None

Returns:

      None
        
    """
    pass
        

def CeRemoveDirectory(lpPathName:'str') -> 'None':
    """
    Removes an existing directory

Args:

      lpPathName(str):Name of the path to remove.

Returns:

      None
        
    """
    pass
        

def CeGetTempPath() -> 'str':
    """
    Obtains the temp path on the device.

Args:



Returns:

      str
        
    """
    pass
        

def CeGetSystemInfo() -> 'typing.Any':
    """
    Retrieves information about the CE device.

Args:



Returns:

      typing.Any:Search for GetSystemInfo at msdn, google or google groups.
Return ValueThe return value is a tuple of 9 values, which corresponds 

to the Win32 SYSTEM_INFO structure.  The element names are: 

dwOemIddwPageSizelpMinimumApplicationAddresslpMaximumApplicationAddress, 

dwActiveProcessorMaskdwNumberOfProcessors 

dwProcessorTypedwAllocationGranularity(wProcessorLevel,wProcessorRevision)

        
    """
    pass
        

def CeGetDesktopDeviceCaps() -> 'typing.Any':
    """
    Retrieves information about the CE desktop.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CeGetSystemMetrics() -> 'typing.Any':
    """
    Retrieves information about the CE system.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CeGetSpecialFolderPath() -> 'str':
    """
    Retrieves the location of special folders on the CE device.

Args:



Returns:

      str
        
    """
    pass
        

def CeGetStoreInformation() -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves information about store on the CE system.

Args:



Returns:

      typing.Tuple[typing.Any, typing.Any]:wincerapi.CeGetStoreInformation

int, int = CeGetStoreInformation()Retrieves information about store on the CE system.
Return ValueThe result is a tuple of (storeSize, freeSize)

        
    """
    pass
        

def CeGetSystemPowerStatusEx() -> 'typing.Any':
    """
    Retrieves the power status of the CE device.

Args:



Returns:

      typing.Any:wincerapi.CeGetSystemPowerStatusEx

tuple = CeGetSystemPowerStatusEx()Retrieves the power status of the CE device.
Return ValueThe result is a tuple of (ACLineStatus, BatteryFlag, BatteryLifePercent, BatteryLifeTime, BatteryFullLifeTime, BackupBatteryFlag, BackupBatteryLifePercent, BackupBatteryLifeTime, BackupBatteryLifeTime);

        
    """
    pass
        

def CeSHCreateShortcut() -> 'None':
    """
    Creates a shortcut on the remote device.

Args:



Returns:

      None
        
    """
    pass
        

def CeSHGetShortcutTarget() -> 'typing.Any':
    """
    Retrieves the target of a shortcut.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CeGetVersionEx() -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, str]':
    """
    Returns the current version of Windows, and information about the environment for the CE device.

Args:



Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, str]:wincerapi.CeGetVersionEx

(int,int,int,int,string) = CeGetVersionEx()Returns the current version of Windows, and information about the environment for the CE device.
Return ValueThe return value is a tuple with the following information.

        
    """
    pass
        

def CeGlobalMemoryStatus() -> 'typing.Any':
    """
    Returns information about current memory availability.

Args:



Returns:

      typing.Any:wincerapi.CeGlobalMemoryStatus

tuple = CeGlobalMemoryStatus()Returns information about current memory availability.
Return ValueThe return value is a tuple with the following information.

        
    """
    pass
        

def FindFiles(fileSpec:'str') -> 'typing.Any':
    """
    Retrieves a list of matching filenames on the CE device.  An interface to the API CeFindFirstFile/CeFindNextFile functions.

Args:

      fileSpec(str):A string that specifies a valid directory or path and filename, which can contain wildcard characters (* and ?).Win32 API References

Returns:

      typing.Any:Search for CloseHandle at msdn, google or google groups.
Return ValueThe return value is a list of tuples, in the same format as the WIN32_FIND_DATA structure:
Items
        
    """
    pass
        

def CeGetFileAttributes(fileName:'str') -> 'typing.Any':
    """
    Determines a files attributes.

Args:

      fileName(str):Name of the file to retrieve attributes for.

Returns:

      typing.Any
        
    """
    pass
        

def CeSetFileAttributes(filename:'str',newAttributes:'typing.Any') -> 'None':
    """
    Changes a file's attributes.

Args:

      filename(str):filename
      newAttributes(typing.Any):attributes to set

Returns:

      None
        
    """
    pass
        

def CeGetFileSize() -> 'typing.Any':
    """
    Determines the size of a file.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CeReadFile(hFile:'typing.Union[typing.Any, int]',bufSize:'typing.Any') -> 'str':
    """
    Reads a file from the CE device.

Args:

      hFile(typing.Union[typing.Any, int]):Handle to the file
      bufSize(typing.Any):Size of the buffer to create for the read.

Returns:

      str
        
    """
    pass
        

def WriteFile(hFile:'typing.Union[typing.Any, int]',data:'str') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Writes a string to a file

Args:

      hFile(typing.Union[typing.Any, int]):Handle to the file
      data(str):The data to write.Return ValueThe result is a tuple of (errCode, nBytesWritten). errCode will always be zero (until overlapped IO is supported!)

Returns:

      typing.Tuple[typing.Any, typing.Any]:The data to write.Return ValueThe result is a tuple of (errCode, nBytesWritten). 

errCode will always be zero (until overlapped IO is supported!)

        
    """
    pass
        
CSIDL_BITBUCKET = ...
CSIDL_COMMON_DESKTOPDIRECTORY = ...
CSIDL_COMMON_PROGRAMS = ...
CSIDL_COMMON_STARTMENU = ...
CSIDL_COMMON_STARTUP = ...
CSIDL_CONTROLS = ...
CSIDL_DESKTOP = ...
CSIDL_DESKTOPDIRECTORY = ...
CSIDL_DRIVES = ...
CSIDL_FONTS = ...
CSIDL_NETHOOD = ...
CSIDL_NETWORK = ...
CSIDL_PERSONAL = ...
CSIDL_PRINTERS = ...
CSIDL_PROGRAMS = ...
CSIDL_RECENT = ...
CSIDL_SENDTO = ...
CSIDL_STARTMENU = ...
CSIDL_STARTUP = ...
CSIDL_TEMPLATES = ...
